
***--------------------------------------------------------------------------***
 //* Chade and Lindenlaub
 //* Risky Matching
 //* December 2020
 //* Replication Codes
 //* 
 //*
 //* Description of file.
 //*
 //* This code computes the summary statistics and creates descriptive graphs 
 //* displayed in the empirical appendix. 
 //* 
***--------------------------------------------------------------------------***

clear  		all
capture 	log close
set 		more off 
 
cd 			"~/Replication_Codes_submit/Appendix_Figures"
global		wagedata "~/Replication_Codes_submit/Wage_Data"
global		onet "~/Replication_Codes_submit/Occupational_Tasks/ONET"
global		dot "~/Replication_Codes_submit/Occupational_Tasks/DOT"

*ssc 		install blindschemes

***--INCOME STATISTICS-------------------------------------------------------***

* import data
use 		"$wagedata/cps_data.dta", clear

//EARLY PERIOD
preserve

* select early period
keep 		if year>=1979 & year <=1981

* merge with y-data (from the DOT)
merge 		m:1 occ1990 using "$dot/dot_final.dta"   							 // merging in early period occupation attributes
keep 		if _merge==3
drop 		_merge 
save		early_period.dta, replace

restore

// LATER PERIOD

* select later period
keep 		if year>=2015 & year <= 2017

* merge with y-data (from the ONET)
merge 		m:1 occ1990 using "$onet/onet_final.dta" 							 // merging in later period occupation attributes
keep 		if _merge==3 
drop 		_merge 

append		using early_period.dta
erase 		early_period.dta

* prepare data further
gen 		year_grouped =1
replace 	year_grouped =2 if year >=2015 & year <=2017
drop 		year
order 		year_grouped, first
sort 		year_grouped wage1999_level

save 		temp.dta, replace


* Figure: wage cdfs (Figure 3 in the online appendix of the paper)
bys 		year_grouped: cumul wage1999_level, gen(cumul_wage1999_level)
twoway 		(line cumul_wage1999_level wage1999_level if year_grouped == 1, lcolor(blue) lpattern(solid) lwidth(thin)) (line cumul_wage1999_level wage1999_level if year_grouped == 2, lcolor(red) lpattern(solid) lwidth(thin)), xtitle("Monthly wage", size(small)) ytitle(" ", size(small)) xlabel(0[3000]13000) legend(order(1 "data 1979-81" 2 "data 2015-17") size(vsmall)) scheme(plotplain) caption("Note: This graph shows the cdf's of monthly wages for both periods. The early period" "includes the years 1979-81 and the later period the years 2015-17. Wages are" "adjusted for inflation using the consumer price index in 1999.", size(small))
gr 			export "Figure3_OnlineAppendix.eps", replace



* summary statistics incl. college share, CP, income ratios

local 		yr "1 2"

foreach 	yr in 1 2 {

	use 		temp.dta, clear

	tempname 	mat_SS_`yr'
	mat 		mat_SS_`yr'=J(1,8,.) 
	
	qui sum 	wage1999_level if year_grouped == `yr', d

	mat 		mat_SS_`yr'[1,1] 	= r(N)
	mat 		mat_SS_`yr'[1,2] 	= r(mean)
	mat 		mat_SS_`yr'[1,3] 	= r(sd)
	scalar 		define p90_`yr' 	= r(p90)	
	scalar 		define p10_`yr' 	= r(p10)	
	scalar 		define p50_`yr' 	= r(p50)
	scalar 		define p75_`yr' 	= r(p75)
	scalar 		define p25_`yr' 	= r(p25)
	mat 		mat_SS_`yr'[1,4] 	= p90_`yr' / p10_`yr'
	mat 		mat_SS_`yr'[1,5] 	= p90_`yr' / p50_`yr'
	mat 		mat_SS_`yr'[1,6] 	= p75_`yr' / p25_`yr'

	sum 		wage1999_level if year_grouped == `yr' & educ_dummy_detailed == 0, d
	scalar 		define wage_nocol_`yr'		= r(mean)
	sum 		wage1999_level if year_grouped == `yr' & educ_dummy_detailed == 1, d
	scalar 		define wage_col_`yr' 		= r(mean)
	mat 		mat_SS_`yr'[1,7] 	= wage_col_`yr' / wage_nocol_`yr' 			 // skill premium

	sum 		educ_dummy_detailed if year_grouped == `yr'
	mat 		mat_SS_`yr'[1,8] 	= r(mean) 									 // college share

	putexcel 	set "SS_appendix_`yr'.xlsx", replace
	putexcel A1 = ("year") B1 = ("N") C1 = ("mean") D1 = ("sd") E1 = ("ratio9010") F1 = ("ratio9050") G1 = ("ratio7525") H1 =("CP") I1 = ("collegeshare") A2 = ("`yr'") B2=matrix(mat_SS_`yr')

	import 		excel SS_appendix_`yr'.xlsx, firstrow clear
	erase 		SS_appendix_`yr'.xlsx
	save 		SS_appendix_`yr'.dta, replace

}

use 		SS_appendix_1.dta, clear
append 		using SS_appendix_2.dta

export 		delimited "Table3_OnlineAppendix.csv", replace

erase 		SS_appendix_1.dta
erase 		SS_appendix_2.dta
erase 		temp.dta




***--G DISTRIBUTION----------------------------------------------------------***

//EARLY PERIOD

* import data
import 		delimited "$wagedata/G_expanded_early.csv", clear					 // vector of y's in population

* summary statistics
tempname 	mat_G_t1
mat 		mat_G_t1=J(1,3,.) 

qui 		sum y, d
return 		list
mat 		mat_G_t1[1,1] 	= r(N)
mat 		mat_G_t1[1,2] 	= r(mean)
mat 		mat_G_t1[1,3] 	= r(sd)

putexcel 	set "G_early_table.xlsx", replace
putexcel 	A1 = ("Year") B1 = ("N") C1 = ("Mean") D1 = ("St. Deviation") A2 =("1979-81") B2 = matrix(mat_G_t1)

import 		excel G_early_table.xlsx, firstrow clear
erase 		G_early_table.xlsx
save 		G_early_table.dta, replace

	
//LATER PERIOD

* import data
import 		delimited "$wagedata/G_expanded_later.csv", clear

* summary statistics
tempname 	mat_G_t2
mat 		mat_G_t2=J(1,3,.) 
qui 		sum y, d
return 		list
mat 		mat_G_t2[1,1] 	= r(N)
mat 		mat_G_t2[1,2] 	= r(mean)
mat 		mat_G_t2[1,3] 	= r(sd)

putexcel 	set "G_later_table.xlsx", replace
putexcel 	A1 = ("Year") B1 = ("N") C1 = ("Mean") D1 = ("St. Deviation") A2 =("2015-17") B2 = matrix(mat_G_t2)

import 		excel G_later_table.xlsx, firstrow clear
erase 		G_later_table.xlsx
save 		G_later_table.dta, replace

*** put both periods together
use 		G_early_table.dta
append 		using G_later_table.dta

export 		delimited "Table5_OnlineAppendix.csv", replace

erase 		G_early_table.dta
erase 		G_later_table.dta




***--Q DISTRIBUTION----------------------------------------------------------***

//EARLY PERIOD

* prepare data
import 		delimited "$wagedata/Q_early.csv", clear
expand 		weight
sort 		afqt_std
drop 		weight

* summary statistics
tempname 	mat_Q_t1
mat 		mat_Q_t1=J(1,3,.) 
qui 		sum afqt_std, d
return 		list
mat 		mat_Q_t1[1,1] 	= r(N)
mat 		mat_Q_t1[1,2] 	= r(mean)
mat 		mat_Q_t1[1,3] 	= r(sd)

putexcel 	set "Q_early_table.xlsx", replace
putexcel 	A1 = ("Year") B1 = ("N") C1 = ("Mean") D1 = ("St. Deviation") A2 =("1979-81") B2 = matrix(mat_Q_t1)

import 		excel Q_early_table.xlsx, firstrow clear
erase 		Q_early_table.xlsx
save 		Q_early_table.dta, replace


//LATER PERIOD

* prepare data
import 		delimited "$wagedata/Q_later.csv", clear
expand 		weight
sort 		afqt_std
drop 		weight

* summary statistics
tempname 	mat_Q_t2
mat 		mat_Q_t2=J(1,3,.) 
qui 		sum afqt_std, d
return 		list
mat 		mat_Q_t2[1,1] 	= r(N)
mat 		mat_Q_t2[1,2] 	= r(mean)
mat 		mat_Q_t2[1,3] 	= r(sd)

putexcel 	set "Q_later_table.xlsx", replace
putexcel 	A1 = ("Year") B1 = ("N") C1 = ("Mean") D1 = ("St. Deviation") A2 =("2015-17") B2 = matrix(mat_Q_t2)

import 		excel Q_later_table.xlsx, firstrow clear
erase 		Q_later_table.xlsx
save 		Q_later_table.dta, replace

*** put both periods together
use 		Q_early_table.dta
append 		using Q_later_table.dta
erase 		Q_early_table.dta
erase 		Q_later_table.dta

export 		delimited "Table4_OnlineAppendix.csv", replace













