%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Chade and Lindenlaub
% Risky Matching
% December 2020
% Replication Codes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Description of file.

% This file performs a decomposition of changes in wage inequality in
% the counterfactual model with exogenous theta^*
% into the different sources, namely: G,Q,H_1,L,f.

% Comment: In the code below, '1980' refers to 1979-1981 (the early period)
% and '2015' refers to 2015-2017 (the later period)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Set-up

clear all;

% Set a working directory
cd('~/Replication_Codes_submit/Estimation/Counterfactuals_Code')
addpath(genpath('~/Replication_Codes_submit'));
addpath(genpath('~/Replication_Codes_submit/Estimation'));
addpath(genpath('~/Replication_Codes_submit/Wage_Data'));

% Distribution of alpha
distribution            =0;                                                 % choose distribution, either truncated normal (==1) or normal (==0)

% structure
global Par                                                                  % Parameters structure
global G    

% primitive = 1: all 1980
% primitive = 2: switch on G
% primitive = 3: switch on H1
% primitive = 4: switch on Q
% primitive = 5: switch on L
% primitive = 6: switch on f
% primitive = 7: switch on f, H1, G 
% primitive = 8: switch on change in education ability cutoff (Theta^*)
% primitive = 9: all 2015

for primitive = 1:9                                                              

% random seed
rng(1984); 

%% Specify counterfactual cases and create storage matrices

if primitive == 1                                                           % 1980
    G_distribution      =1;
    H1_distribution     =1;
    Q_distribution      =1;
    L_distribution_tau  =1; 
    f_prod              =1;
    educ                =1;
elseif primitive == 2                                                       % G from 2015
    G_distribution      =2;
    H1_distribution     =1;
    Q_distribution      =1;
    L_distribution_tau  =1;
    f_prod              =1;
    educ                =1;
elseif primitive == 3                                                       % H1 from 2015
    G_distribution      =1;
    H1_distribution     =2;
    Q_distribution      =1;
    L_distribution_tau  =1;
    f_prod              =1;
    educ                =1;
elseif primitive == 4                                                       % Q from 2015
    G_distribution      =1;
    H1_distribution     =1;
    Q_distribution      =2;
    L_distribution_tau  =1;
    f_prod              =1;
    educ                =1;
elseif primitive == 5                                                       % L from 2015
    G_distribution      =1;
    H1_distribution     =1;
    Q_distribution      =1;
    L_distribution_tau  =2;
    f_prod              =1;
    educ                =1;
elseif primitive == 6                                                       % f from 2015
    G_distribution      =1;
    H1_distribution     =1;
    Q_distribution      =1;
    L_distribution_tau  =1;
    f_prod              =2;
    educ                =1;
elseif primitive == 7                                                       % skill premium from 2015
    G_distribution      =2;
    H1_distribution     =2;
    Q_distribution      =1;
    L_distribution_tau  =1;
    f_prod              =2;
    educ                =1;
elseif primitive == 8                                                       % education ability threshold from 2015
    G_distribution      =1;
    H1_distribution     =1;
    Q_distribution      =1;
    L_distribution_tau  =1;
    f_prod              =1;
    educ                =2;
elseif primitive == 9                                                       % 2015
    G_distribution      =2;
    H1_distribution     =2;
    Q_distribution      =2;
    L_distribution_tau  =2;
    f_prod              =2;
    educ                =2;
end

% create storage matrices
if primitive == 1                   
    Decomp_skillpremium_sep=zeros(9,2);                                     % as many rows as counterfactuals
    Decomp_7525_sep=zeros(9,2);
end

%% Set parameters

%- Import estimated parameters for both periods
load('gmm_output_1980original_fminsearch_fixedtheta.mat','X')
params_1        =X;                                                         % 1980

load('gmm_output_2015original_fminsearch_fixedtheta.mat','X')
params_2        =X;                                                         % 2015

%- Utility function risk aversion parameter (CRRA)
Par.sigma       =1.1;                                                       % sigma >0 and sigma !=1

%- Production function 
if f_prod  ==1   
    Par.q       =params_1(3);
    Par.beta    =params_1(4);
    Par.gamma   =params_1(5);
    Par.K       =params_1(6);
else
    Par.q       =params_2(3);
    Par.beta    =params_2(4);
    Par.gamma  	=params_2(5);
    Par.K       =params_2(6);
end

Par.r           =1;

%- Alpha-shock distribution
Par.Ngrid_alpha =1000; 

if L_distribution_tau==1   
    Par.tau=params_1(2);                                                    % std deviation of shock alpha, 1980
else
    Par.tau=params_2(2);                                                    % std deviation of shock alpha, 2015
end

Par.alphabar=0;                                                             % mean of shock alpha

% parameters of alpha-distribution
if distribution ==1   
    Par.alpha_lb=Par.alphabar*0.1;                                          % for truncated normal: make the support symmetric around mean and positive
    Par.alpha_ub=Par.alphabar*1.9;
    % Check if lower bound of alpha is nonnegative
    if Par.alpha_lb<0
        disp('Negative alpha. Possibly change the lower bound of alpha !');
        return;
    end
else
    Par.alpha_lb=Par.alphabar-3*Par.tau;                                    % for normal: +- 3 standard deviations around the mean
    Par.alpha_ub=Par.alphabar+3*Par.tau;   
end
    
% grid for alpha-shock
G.alphamat  =linspace(Par.alpha_lb,Par.alpha_ub,Par.Ngrid_alpha);           % support of alpha shock 
alphamat_f  =Par.q*exp(Par.r*G.alphamat);                                   % Version f

% pdf 
alpha_pdf_aux =normpdf(G.alphamat,Par.alphabar,Par.tau);                
alpha_pdf     =alpha_pdf_aux/sum(alpha_pdf_aux);                      
clear alpha_pdf_aux; 


%- Firm distribution G 
if G_distribution ==1   
    G.G_dist=importdata('Wage_Data/G_expanded_sample_early.csv');           % G_dist.data is the vector of y's from the data, 1980
else
    G.G_dist=importdata('Wage_Data/G_expanded_sample_later.csv');           % G_dist.data is the vector of y's from the data, 2015
end

%- Skill distribution H
Par.Ngrid_x  =1000;
G.xmat       =linspace(1/Par.Ngrid_x,1,Par.Ngrid_x);                        % skill x-grid

% uneducated skill distribution Hn
Par.b_n      =1;                                                            % b_n = 1: uniform distribution

% educated skill distribution He
if H1_distribution ==1   
    Par.b_e=params_1(1);                                                    % 1980                     
else
    Par.b_e=params_2(1);                                                    % 2015                        
end

xe_cdf    =(G.xmat).^Par.b_e;                                               % H_e: cdf of educated          
xn_cdf    =(G.xmat).^Par.b_n;                                               % H_n: cdf of non-educated

xe_pdf    =(xe_cdf-[0,xe_cdf(1:end-1)]);                                    % generate pdf from cdf 
xn_pdf    =(xn_cdf-[0,xn_cdf(1:end-1)]);                                    % generate pdf from cdf 

%- Ability distribution Q 
if Q_distribution ==1   
    G.q_dist=importdata('Wage_Data/Q_early.csv');                           % q_dist.data is the vector of theta's from the data
    G.q_dist.data=repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));           % 1980
else 
    G.q_dist=importdata('Wage_Data/Q_later.csv');                           % q_dist.data is the vector of theta's from the data
    G.q_dist.data=repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));           % 2015
end

% Fix theta^* exogenously   % (from data: backed out from empirical college share)
q                   = G.q_dist.data;                                        % q frequencies
[Q, p]              = ecdf(q);                                              % evalulate empirical ability distribution Q at different ability values (here denoted by p), input is the vector of theta's from the data

if educ == 2
    Col_Share       = csvread('Wage_Data/college_share.csv',1,0);                  
    Col_Share       = mean(Col_Share(40:42,2));                             % College Share 2015 (1-Q(theta))
    Q_theta         = 1-Col_Share;
else 
    Col_Share       = csvread('Wage_Data/college_share.csv',1,0);
    Col_Share       = mean(Col_Share(4:6,2));                               % College Share 1980 (1-Q(theta))
    Q_theta         = 1-Col_Share;                                          % find theta that corresponds to Q_theta
end 

dist                = abs(Q - Q_theta);                                     % distance between Q(theta) and the empirical Q_theta, where Q_theta==1-Col_Share
minDist             = min(dist);                                            % find minimum distance
idx                 = find(dist == minDist);
Par.theta           = p(idx);                                               % find theta that corresponds to Q_theta

%- Number of individuals we simulate
Par.sim_no  =length(G.G_dist.data);                                         % equals the number of jobs in the data

%- Discounting
Par.disc    =1/(1+0.04/12);                                                 % monthly

%- Housekeepinh

clear idx Q p q Col_Share  Q_theta dist minDist

%----------------------------- SOLVE THE MODEL ---------------------------%

%% Solve for matching function

% ability cdf
[Q, p]=ecdf(G.q_dist.data);                                                 % evalulate empirical ability distribution Q at different ability values (here denoted by p), input is the vector of theta's from the data

dist    = abs(p - Par.theta);                                               % find ability level p that is closest to theta
minDist = min(dist);
idx     = find(dist == minDist);
Q_theta = Q(idx);                                                           % evaluate Q at theta --> Q(theta)

check_q=size(Q_theta);
if check_q(1,1)>1
    disp('Error in Q')
end

Q_theta = max(Q_theta);                                                     % Q_theta should is unique (unless error pops up) but if it is not, pick max of the vector

% skill cdf
x_cdf           =Q_theta*xn_cdf + (1-Q_theta)*xe_cdf;                       % H(x) is mixture of H_n and H_e, ability is distributed according to Q
% skill pdf
x_pdf           =Q_theta*xn_pdf + (1-Q_theta)*xe_pdf;                       % h(x) is mixture of h_n and h_e, ability is distributed according to Q

%- matching function (matching firms to workers top to bottom)

% first expand skill distribution according to number of workers (which equals the number of jobs)
x_tentsd        =round(x_pdf.*Par.sim_no);                                  % simulate workers (Par.sim_no is number of workers we simulate)
x_tentsd(x_tentsd==0)=1;                                                    % ensure there is some mass at all gridpoints of x
numb_workers    =sum(x_tentsd);

% expand skill grid according to number of workers
G.xmat_expand_aux = repelem(G.xmat,x_tentsd)';                              % get skill distribution for the workers                                                 

% determine the number of idle workers/firms (determine the imbalance due to rounding)
y_idle=Par.sim_no-numb_workers;

if  y_idle>=0                                                               % case: too few workers
    mumat_aux =G.G_dist.data';                                              % match up workers with firms top to bottom, with some idle firms at the bottom --> drop  
    x_draw=randsample(G.xmat_expand_aux,y_idle, true);                      % draw as many additional workers as needed 
    G.xmat_expand=[G.xmat_expand_aux;x_draw];                               % append additional workers to x-distribution
    G.xmat_expand=sort(G.xmat_expand);                                      % sort extended x-distribution bottom to top
elseif y_idle<0                                                             % case: too many workers
    y_draw=randsample(G.G_dist.data,-y_idle, true);                         % draw as many additional firms as needed 
    mumat_aux = [G.G_dist.data; y_draw]';                                   % append additional firms to y-distribution
    mumat_aux = sort(mumat_aux);                                            % sort the extended y-distribution bottom to top
    G.xmat_expand=G.xmat_expand_aux;
end

% matching
matching_aux    =[G.xmat_expand mumat_aux'];                                % col 1 worker types (x), col 2 job/firm types (y)

%- compute y-type as the mean of y-types for each x-type
groups          =findgroups(matching_aux(:,1));                             % generate x type identifier 
matching        =[G.xmat_expand mumat_aux' groups];                         % col 1 worker types (x), col 2 job types (y), col 3 worker type identifier (groups)

y_mean_aux      =splitapply(@mean,matching(:,2),groups);                    % mean y for each x-type 
y_mean          =[y_mean_aux unique(groups)];                               % mean y for each x-type (indicated by group type)

matching_x_groups=[matching(:,1) matching(:,3)];
matching_x_groups=unique(matching_x_groups, 'rows');                        % contains unique x-types and identifiers

matching_x_groups_ymean=[matching_x_groups y_mean];

check           = matching_x_groups_ymean(:,2)-matching_x_groups_ymean(:,4);
if check>0
    disp('Error in Matching')
end

matching_final  =[matching_x_groups_ymean(:,1) matching_x_groups_ymean(:,3)]; % col 1 x-types; col 2 matched AVERAGE y-types

mumat           =matching_final(:,2)';                                      % final matching (1x1000 vector): gives y-type for each x-type

%- housekeeping
clear check_q Q p q idx G.xmat_expand_aux y_idle mumat_aux x_draw y_draw matching_aux groups matching y_mean_aux y_mean matching_x_groups matching_x_groups_ymean check matching_final dist minDist; 


%% Solve for Wage Function (numerical integration)

mumat_gamma = mumat.^Par.gamma;                                             % mu^gamma
xmat_beta =Par.beta * G.xmat.^(Par.beta -1);                                % derivative of x^beta w.r.t x
 
integ =xmat_beta.*mumat_gamma;                                              % integrand
dinteg =0.5*(integ(2:end)+integ(1:end-1));                                  % take midpoints of integrand
dxmat =G.xmat(2:end)-G.xmat(1:end-1);                                       % dx
wmat =[0,cumsum(dinteg.*dxmat)];                                            % numerical integration

%- housekeeping
clear mumat_gamma xmat_beta integ dinteg dxmat;

%% Worker's Utility (consume all income)

% consumption state: x, alpha
C       =repmat(wmat',[1 Par.Ngrid_alpha]).* ...
permute(repmat(alphamat_f',[1 Par.Ngrid_x]),[2 1])+Par.K;                   % multiply wage integral by shock exp(r*alpha) and TFP

% utility from consumption
penalty =-10^6;
U       = (C.^(1-Par.sigma)-1)/(1-Par.sigma);                               % crra
U(C<0)  = penalty;

% skill pdf
xpbmat  = repmat(x_pdf',[1 Par.Ngrid_alpha]);                               % skill pdf of both
xnpbmat = repmat(xn_pdf',[1 Par.Ngrid_alpha]);                              % skill pdf non-educated
xepbmat = repmat(xe_pdf',[1 Par.Ngrid_alpha]);                              % skill pdf educated

% alpha pdf
alphapbmat =permute(repmat(alpha_pdf', [1 Par.Ngrid_x]),[2 1]);             % pdf of alpha, reshaped

% expected utility for non-educated and educated workers
Un      = sum(sum(U.*xnpbmat.*alphapbmat,1),2);                             % expected utility for non-educated (integrate out x and alpha)
Ue      = sum(sum(U.*xepbmat.*alphapbmat,1),2);                             % expected utility for educated (integrate out x and alpha)                       
                                        
    


%----------------------------- PRODUCE MOMENTS ---------------------------%
 

% 1) Education

% %- M1. Share of
% 
% M1 = 1-Par.theta;


% 2) Wage and Income Moments

%- M2. College Premium

% College Premium(wage)
E_e             =sum(sum(C.*xepbmat.*alphapbmat,1),2);                      % ... conditional on skill distribution of educated
E_n             =sum(sum(C.*xnpbmat.*alphapbmat,1),2);                      % ... conditional on skill distribution of non-educated
CP              =E_e./E_n;

M2              =CP;                                                    

%- M3-7. Percentiles of Income Distribution

% expand vector of wages by pdf over x's
wage_pdf = repelem(wmat,x_tentsd);                                          % get wage distribution for the workers                                                 

% for each individual, get shock draw from L distribution
if distribution ==1                                                         % truncated normal pdf
    Ndraw       = numel(wage_pdf);
    for i=1:Ndraw
    one_draw = trandn(Par.alpha_lb, Par.alpha_ub);                          % draws from truncated normal
    draw(:, i) = one_draw;
    end
else                                                                        % normal pdf
    Ndraw       = numel(wage_pdf);
    draw        = normrnd(Par.alphabar,Par.tau,[1,Ndraw]);                  % draws from normal
end

% shock parameter 
shock   = Par.q*exp(Par.r*draw);                                            % multiply by shock by TFP 

% vector of incomes
income_pdf = wage_pdf.*shock+Par.K;                                         % for each agent: get income (multiply wage by shock term)
                                                                   
% percentiles empirical pdf                                                 % in all of the percentile variables, first number is approx. percentile and second number is actual value
pct_5  = prctile(income_pdf, 5, 2);
pct_25 = prctile(income_pdf, 25, 2);
pct_50 = prctile(income_pdf, 50, 2);
pct_75 = prctile(income_pdf, 75, 2);
pct_95 = prctile(income_pdf, 95, 2);

M3M7   = [pct_5 pct_25 pct_50 pct_75 pct_95];

%% Store results
 
% absolute levels
Decomp_skillpremium_sep(primitive,1)=M2;
Decomp_7525_sep(primitive,1)=pct_75/pct_25;

% percentage changes relative to 1980 (zero changes here, since this is 1980)
Decomp_skillpremium_sep(primitive,2)=(M2-(Decomp_skillpremium_sep(1,1)))/(Decomp_skillpremium_sep(1,1));
Decomp_7525_sep(primitive,2)=(pct_75/pct_25-Decomp_7525_sep(1,1))/Decomp_7525_sep(1,1);

end

%% Finalize matrices
names = {'1980'; 'G'; 'H1'; 'Q'; 'L'; 'f'; 'Skill Premium';'Educ' ;'2015'};
Decomp_skillpremium_sep = [num2cell(Decomp_skillpremium_sep) names];
Decomp_7525_sep = [num2cell(Decomp_7525_sep) names];

save ('Decomp_skillpremium_sep_fixedtheta.mat','Decomp_skillpremium_sep');
save ('Decomp_7525_sep_fixedtheta.mat','Decomp_7525_sep');

% housekeeping
clearvars -except Decomp_skillpremium_sep Decomp_7525_sep



