%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Chade and Lindenlaub
% Risky Matching
% December 2020
% Replication Codes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%% Description of file.
%
% This file specifies exogenous parameters and defines the estimation 
% problem.
%
% Model: counterfactual model with fixed theta* (from data). So theta* 
% is a parameter and lambda does not need to be estimted 
% (and therefore we do not target college share in the data). 
%
% Instructions: follow these steps
%   - 1.: In line 53 of this code, set "year = "1980original"
%   - 2.: run "gmm_estimation_inputs_fixedtheta_final.m"
%   - 3.: run "gmm_call_fixedtheta_final.m"
%   - 4.: In line 53 of this code, set "year = "2015original"
%   - 5.: run "gmm_estimation_inputs__fixedtheta_final.m"
%   - 6.: run "gmm_call_fixedtheta_final.m"
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%% Pre-set parameters and make some choices 

%----------------------------- PRE-SET PARAMETERS -------------------------%

clear all;

global Par                                                                  % Parameters strcture
global G                                                                    % Grids structure
global distribution                                                         % Distribution of alpha

cd('~/Replication_Codes_submit/Estimation/Counterfactuals_Code')
addpath(genpath('~/Replication_Codes_submit/Estimation/Weighting_Matrix'));
addpath(genpath('~/Replication_Codes_submit/Wage_Data'));

%------------------------------ Make Some Choices -------------------------%

% Distribution of alpha
distribution    = 0;                                                        % choose distribution, either truncated normal (==1) or normal (==0)

% Years

% year = '2015original' --> years 2015-2017
% year = '1980original' --> years 1979-81

year            = "1980original";   %"2015original"

% Seed
Par.seed        =1984;


%% Load Moments and Weighting Matrix

if year == "2015original"
    
    % M2: College Premium
    Col_Prem    =csvread('Wage_Data/college_premium.csv',1,5);
    Mdata2015   =mean(Col_Prem(40:42,1));

    % M3-7: Income Percentiles
    Inc_Perc    =csvread('Wage_Data/percentiles.csv',1,0);
    Mdata2015   =[Mdata2015 Inc_Perc(1,2) Inc_Perc(5,2) Inc_Perc(10,2) Inc_Perc(15,2) Inc_Perc(19,2)];

    % M8: Mean Income
    Inc_Mom     =csvread('Wage_Data/moments.csv',1,1);
    Mdata2015   =[Mdata2015 Inc_Mom(2,1)];

    % M9: Std Dev of Income
    Mdata2015   =[Mdata2015 Inc_Mom(2,2)];

    % M10: Var Decomp
    Var_Decomp  =csvread('Wage_Data/inc_var.csv',1,1);
    Mdata2015   =[Mdata2015 Var_Decomp(2,3)/Var_Decomp(2,4)];

    Mdata       =Mdata2015';


elseif year == "1980original"
    
    % M2: College Premium
    Col_Prem    =csvread('Wage_Data/college_premium.csv',1,5);
    Mdata1980   =mean(Col_Prem(4:6,1));

    % M3-7: Income Percentiles
    Inc_Perc    =csvread('Wage_Data/percentiles.csv',1,0);
    Mdata1980   =[Mdata1980 Inc_Perc(1,1) Inc_Perc(5,1) Inc_Perc(10,1) Inc_Perc(15,1) Inc_Perc(19,1)];

    % M8: Mean Income
    Inc_Mom     =csvread('Wage_Data/moments.csv',1,1);
    Mdata1980   =[Mdata1980 Inc_Mom(1,1)];

    % M9: Std Dev of Income
    Mdata1980   =[Mdata1980 Inc_Mom(1,2)];

    % M10: Var Decomp
    Var_Decomp  =csvread('Wage_Data/inc_var.csv',1,1);
    Mdata1980   =[Mdata1980  Var_Decomp(1,3)/Var_Decomp(1,4)];

    Mdata       =Mdata1980';
  
end 


%- Load Weighting Matrix

if year == "2015original"
    Weighting_imp =load('Weighting_Matrix/Weight_later_fixedtheta.mat');
    Weight =Weighting_imp.Weight;

elseif year=="1980original"
    Weighting_imp   =load('Weighting_Matrix/Weight_early_fixedtheta.mat');
    Weight          =Weighting_imp.Weight;

end

%% Set Parameters

% Load empirical G and Q Distributions 
if year == "2015original"
    % load firm distribution G  
    G.G_dist = importdata('Wage_Data/G_expanded_sample_later.csv');         % G_dist.data is the vector of y's from the data
    % load ability distribution Q
    G.q_dist = importdata('Wage_Data/Q_later.csv');                         % q_dist.data is the vector of theta's from the data
    G.q_dist.data = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));

elseif year == "1980original"
    % load firm distribution G  
    G.G_dist = importdata('Wage_Data/G_expanded_sample_early.csv');         % G_dist.data is the vector of y's from the data
    % load ability distribution Q
    G.q_dist = importdata('Wage_Data/Q_early.csv');                         % q_dist.data is the vector of theta's from the data
    G.q_dist.data = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));
end

% Income shock grid
Par.Ngrid_alpha     =1000;
Par.alphabar        =0;                                                     % Mean of alpha shock
Par.r               =1;                                                     % Scale of Shock (normalize to one since not identified)

% utility function risk aversion parameter (CRRA)
Par.sigma           =1.1;                                                   % sigma >0 and sigma !=1 

% skill distribution, H_n and H_e (FOSD)
Par.Ngrid_x         =1000;                                                  % skill x-grid: number of grid points
Par.b_n             =1;                                                     % b_n = 1: uniform distribution
G.xmat              =linspace(1/Par.Ngrid_x,1,Par.Ngrid_x);                 % skill x-grid

% number of individuals we simulate
Par.sim_no          =length(G.G_dist.data);                                 % equals the number of jobs in the data

% Tolerance 
Par.tolerance       =0.00001;
Par.tolerance_nan   =0.0005;

% Effort Cost 
Par.lambda          =1;                                                     % in this counterfactual we can normalize
Par.p               =1;

% Discounting
Par.disc            =1/(1+0.04/12);                                         % monthly


% Fix theta^* exogenously                                                   % (from data: backed out from empirical college share)
if year == "2015original"
    q2              = G.q_dist.data;                                        % q frequencies,2015
    [Q2, p2]        = ecdf(q2);                                             % evalulate empirical ability distribution Q at different ability values (here denoted by p), input is the vector of theta's from the data
    Col_Share_2     = csvread('Wage_Data/college_share.csv',1,0);                  
    Col_Share_2     = mean(Col_Share_2(40:42,2));                            % College Share 2015 (1-Q(theta))
    Q_theta_2       = 1-Col_Share_2;

    dist            = abs(Q2 - Q_theta_2);                                  % distance between Q2(theta) and the empirical Q_theta_1, where Q_theta_1==1-Col_Share_1
    minDist         = min(dist);                                            % find minimum distance
    idx             = find(dist == minDist);
    Par.theta       = p2(idx);                                              % find theta that corresponds to Q_theta_1
else
    q1              = G.q_dist.data;                                        % q frequencies, 1980
    [Q1, p1]        = ecdf(q1);                                             % evalulate empirical ability distribution Q at different ability values (here denoted by p), input is the vector of theta's from the data
    Col_Share_1     = csvread('Wage_Data/college_share.csv',1,0);
    Col_Share_1     = mean(Col_Share_1(4:6,2));                             % College Share 1980 (1-Q(theta))
    Q_theta_1       = 1-Col_Share_1;

    dist            = abs(Q1 - Q_theta_1);                                  % distance between Q2(theta) and the empirical Q_theta_1, where Q_theta_1==1-Col_Share_1
    minDist         = min(dist);                                            % find minimum distance
    idx             = find(dist == minDist);
    Par.theta       = p1(idx);                                              % find theta that corresponds to Q_theta_1
end 

%----------------------------- DEFINE OPTIMIZATION PROBLEM -------------------------%


%// Call Optimization Routine

disp(' ')

%if optimeth=="nelder-mead"
    disp('Optimization method set to Nelder-Mead. Using fminsearch.')
    disp(' ') 
    
    
    if year == "2015original"       

    %- Number of parameters to estimate 
    n_vars=6;    
    %- Define problem structure
    problem.solver                  = 'fminsearch';
    problem.objective               = @(params) moments_fixedtheta_final(G, Par, params, Mdata, Weight);
    
    % starting vector (based on Genetic Algorithm --global maximization-- output)
    problem.x0                      =[34.6743102202097,0.594768500389958,10326.8821560642,0.356301560630919,0.705217658342282,719.462369759021]; 
    
    problem.options                 = optimset('Display','iter', 'MaxFunEvals',15000,'MaxIter',8000, 'PlotFcns',@optimplotfval);  
    %- Save structure
    save ('inputs_gmm_fixedtheta.mat');
    
    
    elseif year=="1980original"    
        
    %- Number of parameters to estimate 
    n_vars=6; 
    %- Define problem structure
    problem.solver                  = 'fminsearch';
    problem.objective               = @(params) moments_fixedtheta_final(G, Par, params, Mdata, Weight);
   
    % starting vector (based on Genetic Algorithm --global maximization-- output)
    problem.x0                      =[8.46646394956854,0.494529931979027,5845.69088792473,0.325081337147523,0.277071798658664,478.731160554159];
    
    problem.options                 = optimset('Display','iter', 'MaxFunEvals',15000,'MaxIter',8000, 'PlotFcns',@optimplotfval); 
    %- Save structure
    save ('inputs_gmm_fixedtheta.mat');

    end


save ('inputs_gmm_fixedtheta.mat');

