%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Chade and Lindenlaub
% Risky Matching
% December 2020
% Replication Codes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%%% Description of file.
%
% This file specifies exogenous parameters and defines the estimation 
% problem.
%
%%% Instructions: follow these steps
%   - 1.: In line 57 of this code, set "year = 1980original"
%           (and keep line 58 commented out)
%   - 2.: run "gmm_estimation_inputs_final.m"
%   - 3.: run "gmm_call_final.m"
%   - 4.: In line 58 of this code, uncomment "year = 2015original"
%   - 5..: run "gmm_estimation_inputs_final.m"
%   - 6.: run "gmm_call_final.m"
%
%%% Comment: In the code below, '1980' refers to 1979-1981 (the early period)
% and '2015' refers to 2015-2017 (the later period)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%% Pre-set parameters and make some choices

%----------------------------- PRE-SET PARAMETERS -------------------------%

clear all;

global Par      % Parameters structure
global G        % Grids structure

cd('~/Replication_Codes_submit/Estimation/Estimation_Code')
addpath(genpath('~/Replication_Codes_submit/Wage_Data'));
addpath(genpath('~/Replication_Codes_submit/Estimation/Weighting_Matrix'));


%------------------------------ Make Some Choices -------------------------%

%%%

% Distribution of alpha
distribution    = 0;                                                        % choose distribution, either truncated normal (==1) or normal (==0)


%%%

% Years

% year = '2015original' --> years 2015-2017 (later period)
% year = '1980original' --> years 1979-81 (early period)

year            = "1980original";
%year            = "2015original";

%%%


%% Load Moments and Weighting Matrix

%- Load Moments

% 1. College Share
% 2. College Premium
% 3-7. Percentiles of the wage distribution: pct_5 pct_25 pct_50 pct_75 pct_95
% 8. Average Wage
% 9. Standard deviation of the wage distribution
% 10. between/within ratio of wage variance decomp

if year == "2015original"
    
    % M1: College Share
    Col_Share   =csvread('Wage_Data/college_share.csv',1,0);
    Mdata2015   =mean(Col_Share(40:42,2));

    % M2: College Premium
    Col_Prem    =csvread('Wage_Data/college_premium.csv',1,5);
    Mdata2015   =[Mdata2015 mean(Col_Prem(40:42,1))];

    % M3-7: Income Percentiles
    Inc_Perc    =csvread('Wage_Data/percentiles.csv',1,0);
    Mdata2015   =[Mdata2015 Inc_Perc(1,2) Inc_Perc(5,2) Inc_Perc(10,2) Inc_Perc(15,2) Inc_Perc(19,2)];

    % M8: Mean Income
    Inc_Mom     =csvread('Wage_Data/moments.csv',1,1);
    Mdata2015   =[Mdata2015 Inc_Mom(2,1)];

    % M9: Std Dev of Income
    Mdata2015   =[Mdata2015 Inc_Mom(2,2)];

    % M10: Var Decomp
    Var_Decomp  =csvread('Wage_Data/inc_var.csv',1,1);
    Mdata2015   =[Mdata2015 Var_Decomp(2,3)/Var_Decomp(2,4)];

    Mdata       =Mdata2015';


elseif year == "1980original"
    
    % M1: College Share
    Col_Share   =csvread('Wage_Data/college_share.csv',1,0);
    Mdata1980   =mean(Col_Share(4:6,2));

    % M2: College Premium
    Col_Prem    =csvread('Wage_Data/college_premium.csv',1,5);
    Mdata1980   =[Mdata1980 mean(Col_Prem(4:6,1))];

    % M3-7: Income Percentiles
    Inc_Perc    =csvread('Wage_Data/percentiles.csv',1,0);
    Mdata1980   =[Mdata1980 Inc_Perc(1,1) Inc_Perc(5,1) Inc_Perc(10,1) Inc_Perc(15,1) Inc_Perc(19,1)];

    % M8: Mean Income
    Inc_Mom     =csvread('Wage_Data/moments.csv',1,1);
    Mdata1980   =[Mdata1980 Inc_Mom(1,1)];

    % M9: Std Dev of Income
    Mdata1980   =[Mdata1980 Inc_Mom(1,2)];

    % M10: Var Decomp
    Var_Decomp  =csvread('Wage_Data/inc_var.csv',1,1);
    Mdata1980   =[Mdata1980 Var_Decomp(1,3)/Var_Decomp(1,4)];

    Mdata       =Mdata1980';    

end 


%- Load Weighting Matrix

if year == "2015original"
    Weighting_imp =load('Weighting_Matrix/Weight_later.mat');
    Weight=Weighting_imp.Weight;
    
elseif year =="1980original"
    Weighting_imp =load('Weighting_Matrix/Weight_early.mat');
    Weight =Weighting_imp.Weight;
    
end


%% Set Parameters and Load Data of Distributions

% Load empirical G and Q Distributions 
if year == "2015original"
    % load firm distribution G  (this is a FREQUENCY distribution, i.e. gives the y-level for each job)
    G.G_dist = importdata('Wage_Data/G_expanded_sample_later.csv');         % G_dist.data is the vector of y's from the data, RANDOM SAMPLE
    % load ability distribution Q
    G.q_dist = importdata('Wage_Data/Q_later.csv');                         % q_dist.data is the vector of theta's from the data
    G.q_dist.data = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));
    
elseif year == "1980original"
    % load firm distribution G  (this is a FREQUENCY distribution, i.e. gives the y-level for each job)
    G.G_dist = importdata('Wage_Data/G_expanded_sample_early.csv');         % G_dist.data is the vector of y's from the data, RANDOM SAMPLE
    % load ability distribution Q
    G.q_dist = importdata('Wage_Data/Q_early.csv');                         % q_dist.data is the vector of theta's from the data
    G.q_dist.data = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));
    
end

% Income Shock
Par.Ngrid_alpha     =1000;                                                  % shock grid
Par.r               =1;                                                     % Scale of Shock (normalize)
Par.alphabar        =0;                                                     % Mean of alpha shock (normalize)

% Utility Function
Par.sigma           =1.1;                                                   % utility function risk aversion parameter (CRRA), sigma >0 and sigma !=1 

% skill distribution, H_n and H_e (FOSD)
Par.Ngrid_x         =1000;                                                  % skill x-grid: number of grid points
Par.b_n             =1;                                                     % b_n = 1: uniform distribution of non-educated
G.xmat              =linspace(1/Par.Ngrid_x,1,Par.Ngrid_x);                 % skill x-grid

% number of individuals we simulate
Par.sim_no          =length(G.G_dist.data);                                 % equals the number of jobs in the data

% Tolerance 
Par.tolerance       =0.00001;
Par.tolerance_nan   =0.0005;

% Seed
Par.seed            =1984;

% Effort Cost (import level of 1980 and keep it fixed in 2015)
if year == "2015original" 
    load('gmm_output_1980original_fminsearch.mat','X')
    Par.lambda=X(1,1);
end

Par.p               =1;


% Discounting
Par.disc            =1/(1+0.04/12);                                         % monthly


%% Define optimization problem

disp(' ')

% // FMINSEARCH ALGORITHM
    
    disp('Optimization method set to Nelder-Mead. Using fminsearch.')
    disp(' ') 
    
    if year == "2015original"       

    %- Number of parameters to estimate (lambda is fixed to 1980-level)
    n_vars=6;    
    
    %- Define problem structure
    problem.solver                  = 'fminsearch';
    problem.objective               = @(params) moments_2015_final(G, Par, params, Mdata, Weight);
    
    % starting vector (based on Genetic Algorithm --global maximization-- output)
    problem.x0                      =[15.9454641152111,0.590991582100664,10462.5775414569,0.358429865828101,0.699123273414712,695.335801922908];
    
    problem.options                 = optimset('Display','iter', 'MaxFunEvals',15000,'MaxIter',8000, 'PlotFcns',@optimplotfval);  
    
    %- Save structure
    save ('inputs_gmm.mat');
    
    

    
    elseif year=="1980original"       
        
    %- Number of parameters to estimate (also estimate lambda)
    n_vars=7; 
    
    %- Define problem structure
    problem.solver                  = 'fminsearch';
    problem.objective               = @(params) moments_1980_final(G, Par, params, Mdata, Weight);
    
    % starting vector (based on Genetic Algorithm --global maximization-- output)
    problem.x0                      = [186.183659434236,6.99268814623356,0.493032348422526,5972.79306989893,0.320674158527013,0.281698531864130,467.167755117343];
    
    problem.options                 = optimset('Display','iter', 'MaxFunEvals',15000,'MaxIter',8000, 'PlotFcns',@optimplotfval); 
    
    %- Save structure
    save ('inputs_gmm.mat');

    end
    
   
      