
function [F, Moments, theta] = moments_1980_final(G, Par, params, Mdata, Weight) 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Chade and Lindenlaub
% Risky Matching
% December 2020
% Replication Codes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Description of file.

% This file inputs parameters, data moments, and the weighting matrix and
% produces moments and the objective function that GMM (GA) will input.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%------------------------------ Preliminaries %---------------------------%

% Distribution of alpha
distribution    = 0;                                                        % choose shock distribution, either truncated normal (==1) or normal (==0)

% Seed
rng(Par.seed)

%---------------INDICATE WHICH PARAMETERS NEED TO BE ESTIMATED -----------%

Par.lambda  =params(1);
Par.b_e     =params(2);
Par.tau     =params(3);
Par.q       =params(4);
Par.beta    =params(5);
Par.gamma   =params(6);
Par.K       =params(7);

iter_vector =[params]

%------------------------------ CONSTRUCT REMAINING OBJECTS ------------%

%- Skill distribution

xe_cdf      =(G.xmat).^Par.b_e;                                             % H_e: cdf of educated          
xn_cdf      =(G.xmat).^Par.b_n;                                             % H_n: cdf of non-educated

xe_pdf      =(xe_cdf-[0,xe_cdf(1:end-1)]);                                  % generate pdf from cdf as the difference between any two cdf values on the grid
xn_pdf      =(xn_cdf-[0,xn_cdf(1:end-1)]);                                  % generate pdf from cdf as the difference between any two cdf values on the grid


%- alpha (shock) distribution

% support
if distribution ==1   
    Par.alpha_lb   =Par.alphabar*0.1;                                       % for truncated normal: make the support symmetric around mean and positive
    Par.alpha_ub   =Par.alphabar*1.9;

    if Par.alpha_lb<0                                                       % check that lower bound of alpha is nonnegative
        disp('Negative alpha. Possibly change the lower bound of alpha !');
    return;
    end
else
    Par.alpha_lb   =Par.alphabar-3*Par.tau;                                 % for normal: +- 3 standard deviations around the mean
    Par.alpha_ub   =Par.alphabar+3*Par.tau;   
end
    
% grid for alpha-shock
G.alphamat  =linspace(Par.alpha_lb,Par.alpha_ub,Par.Ngrid_alpha);           % support of alpha shock 
alphamat_f  =Par.q*exp(Par.r*G.alphamat);                                   % Version f

% pdf 
alpha_pdf_aux =normpdf(G.alphamat,Par.alphabar,Par.tau);                
alpha_pdf     =alpha_pdf_aux/sum(alpha_pdf_aux);                      
clear alpha_pdf_aux; 



%----------------------------- SOLVE THE MODEL -------------------------%

%- Find Equilibrium: Fixed Point in theta


% parameters for iteration
theta0      =0.5;                                                           % initial point for theta
theta       =theta0; 
diff        =1;
crit        =10^-3;
iter        =0;
penalty     =-10^6;

%% Fixed Point Problem (in theta)

while diff>crit                                                             % iterate over theta
    

%% Solve for matching function (here: NOT closed form)

%- ability cdf
[Q, p]  = ecdf(G.q_dist.data);                                              % evalulate empirical ability distribution Q at different ability values (here denoted by p), input G.q_dist.data is the pdf

dist    = abs(p - theta);                                                   % find ability level p that is closest to theta
minDist = min(dist);
idx     = find(dist == minDist);
Q_theta = Q(idx);                                                           % evaluate Q at theta --> Q(theta)


check_q =size(Q_theta);
if check_q(1,1)>1
    disp('Error in Q')
end

Q_theta = max(Q_theta);                                                     % Q_theta should is unique (unless error pops up) but if it is not, pick max of the vector


%- skill cdf
x_cdf           =Q_theta*xn_cdf + (1-Q_theta)*xe_cdf;                       % H(x) is mixture of H_n and H_e, ability is distributed according to Q
%- skill pdf
x_pdf           =Q_theta*xn_pdf + (1-Q_theta)*xe_pdf;                       % h(x) is mixture of h_n and h_e, ability is distributed according to Q

%- matching function (matching firms to workers top to bottom)

% first expand skill distribution according to number of workers (which equals the number of jobs)
x_tentsd        =round(x_pdf.*Par.sim_no);                                  % simulate workers (Par.sim_no is number of workers we simulate)
x_tentsd(x_tentsd==0)=1;                                                    % ensure there is some mass at all gridpoints of x
numb_workers    =sum(x_tentsd);

% expand skill grid according to number of workers
G.xmat_expand_aux = repelem(G.xmat,x_tentsd)';                              % get skill distribution for the workers                                                 

% determine the number of idle workers/firms (determine the imbalance due to rounding)
y_idle=Par.sim_no-numb_workers;

if  y_idle>=0                                                               % case: too few workers
    mumat_aux =G.G_dist.data';                                              % match up workers with firms top to bottom, with some idle firms at the bottom --> drop  
    x_draw=randsample(G.xmat_expand_aux,y_idle, true);                      % draw as many additional workers as needed 
    G.xmat_expand=[G.xmat_expand_aux;x_draw];                               % append additional workers to x-distribution
    G.xmat_expand=sort(G.xmat_expand);                                      % sort extended x-distribution bottom to top
elseif y_idle<0                                                             % case: too many workers
    y_draw=randsample(G.G_dist.data,-y_idle, true);                         % draw as many additional firms as needed 
    mumat_aux = [G.G_dist.data; y_draw]';                                   % append additional firms to y-distribution
    mumat_aux = sort(mumat_aux);                                            % sort the extended y-distribution bottom to top
    G.xmat_expand=G.xmat_expand_aux;
end

% matching
matching_aux    =[G.xmat_expand mumat_aux'];                                % col 1 worker types (x), col 2 job/firm types (y)

%- compute y-type as the mean of y-types for each x-type
groups          =findgroups(matching_aux(:,1));                             % generate x type identifier 
matching        =[G.xmat_expand mumat_aux' groups];                         % col 1 worker types (x), col 2 job types (y), col 3 worker type identifier (groups)

y_mean_aux      =splitapply(@mean,matching(:,2),groups);                    % mean y for each x-type 
y_mean          =[y_mean_aux unique(groups)];                               % mean y for each x-type (indicated by group type)

matching_x_groups=[matching(:,1) matching(:,3)];
matching_x_groups=unique(matching_x_groups, 'rows');                        % contains unique x-types and identifiers

matching_x_groups_ymean=[matching_x_groups y_mean];

check= matching_x_groups_ymean(:,2)-matching_x_groups_ymean(:,4);
if check>0
    disp('Error in Matching')
end

matching_final=[matching_x_groups_ymean(:,1) matching_x_groups_ymean(:,3)]; % col 1 x-types; col 2 matched AVERAGE y-types

mumat=matching_final(:,2)';                                                 % final matching (1x1000 vector): gives y-type for each x-type

%- housekeeping
clear G.xmat_expand_aux y_idle mumat_aux x_draw y_draw matching_aux groups matching y_mean_aux y_mean matching_x_groups matching_x_groups_ymean check matching_final dist minDist; 

%% Solve for Wage Function (numerical integration)

mumat_gamma = mumat.^Par.gamma;                                             % mu^gamma
xmat_beta =Par.beta * G.xmat.^(Par.beta -1);                                % derivative of x^beta w.r.t x
 
integ =xmat_beta.*mumat_gamma;                                              % integrand
dinteg =0.5*(integ(2:end)+integ(1:end-1));                                  % take midpoints of integrand
dxmat =G.xmat(2:end)-G.xmat(1:end-1);                                       % dx
wmat =[0,cumsum(dinteg.*dxmat)];                                            % numerical integration

%- housekeeping
clear mumat_gamma xmat_beta integ dinteg dxmat;

%% Worker's Utility (consume all income)

% consumption state: x, alpha
C       =repmat(wmat',[1 Par.Ngrid_alpha]).* ...
permute(repmat(alphamat_f',[1 Par.Ngrid_x]),[2 1])+Par.K;               % multiply wage integral by shock exp(r*alpha) and TFP

% utility from consumption
U       = (C.^(1-Par.sigma)-1)/(1-Par.sigma);                               % crra
U(C<0)  = penalty;

% skill pdf
xpbmat  = repmat(x_pdf',[1 Par.Ngrid_alpha]);                               % skill pdf of both
xnpbmat = repmat(xn_pdf',[1 Par.Ngrid_alpha]);                              % skill pdf non-educated
xepbmat = repmat(xe_pdf',[1 Par.Ngrid_alpha]);                              % skill pdf educated

% alpha pdf
alphapbmat =permute(repmat(alpha_pdf', [1 Par.Ngrid_x]),[2 1]);             % pdf of alpha, reshaped

% expected utility for non-educated and educated workers
Un      = sum(sum(U.*xnpbmat.*alphapbmat,1),2);                             % expected utility for non-educated (integrate out x and alpha)
Ue      = sum(sum(U.*xepbmat.*alphapbmat,1),2);                             % expected utility for educated (integrate out x and alpha)                       
                                        
                           
%% Update theta
% find new education cutoff
udiff    =Ue-Un;                                                            % difference in expected utility
    
if udiff<0
    newtheta   =0.99;
    disp('nobody chooses investment');
    disp('Setting new theta=0.99...');
else
    newtheta   =(Par.lambda/(udiff/(1-Par.disc)+Par.lambda))^(1/Par.p);     % new theta computed from the marginal individual's indifference condition; change if cost function changes
       
        if newtheta>=1
            disp('nobody chooses investment');
            disp('Setting new theta=0.99...');
            newtheta=0.99; 
        end
        if newtheta<0
            disp('everybody chooses investment');
            disp('Setting new theta=0.01...');
            newtheta=0.01;
        end
end
diff        =abs(theta-newtheta);                                           % converge if this difference is small enough

% Update theta
theta       =newtheta;                                                      % update
iter        =iter+1;
    
end



%----------------------------- PRODUCE MOMENTS ---------------------------%
 

% 1) Education

%- M1. Share of Educated Workers
M1              = 1-Q_theta;

%//

% 2) Wage and Income Moments

%- M2. College Premium

% College Premium(wage)
E_e             =sum(sum(C.*xepbmat.*alphapbmat,1),2);                      % ... conditional on skill distribution of educated
E_n             =sum(sum(C.*xnpbmat.*alphapbmat,1),2);                      % ... conditional on skill distribution of non-educated
CP              =E_e./E_n;

M2              =CP;                                                    

%- M3-M7. Percentiles of Income Distribution

% expand vector of wages by pdf over x's
wage_pdf        = repelem(wmat,x_tentsd);                                   % get wage distribution of workers                                                 

% get draw from L distribution
% distribution chosen above, either truncated normal (==1) or normal (==0)

if distribution ==1                                                         % truncated normal pdf
    Ndraw       = numel(wage_pdf);
    for i=1:Ndraw
    one_draw = trandn(Par.alpha_lb, Par.alpha_ub);                          % draws from truncated normal distribution
    draw(:, i) = one_draw;
    end
else                                                                        % normal pdf
    Ndraw       = numel(wage_pdf);
    draw        = normrnd(Par.alphabar,Par.tau,[1,Ndraw]);                  % draws from normal distribution
end

% shock parameter 
shock   = Par.q*exp(Par.r*draw);                                            % multiply by shock exp(r*alpha)    

% vector of incomes
income_pdf = wage_pdf.*shock+Par.K;                                         % for agent get income (multiply wage by shock term)
                                                                            

% percentiles empirical pdf                                                 % in all of the percentile variables, first number is approx. percentile and second number is actual value
pct_5  = prctile(income_pdf, 5, 2);
pct_25 = prctile(income_pdf, 25, 2);
pct_50 = prctile(income_pdf, 50, 2);
pct_75 = prctile(income_pdf, 75, 2);
pct_95 = prctile(income_pdf, 95, 2);

M3M7   = [pct_5 pct_25 pct_50 pct_75 pct_95];

%- M8. Mean of Income Distribution

% average income: E(wage)
E_I                 =sum(sum(C.*xpbmat.*alphapbmat,1),2); 

M8                  =E_I;

%- M9. Variance (standard deviation) of Income Distribution

% variance of wage: Var(wage)
I_sq                =C.^2;
E_Isq               =sum(sum(I_sq.*xpbmat.*alphapbmat,1),2);                % E(i^2)
EI_sq               =E_I.^2;                                                % (E(i))^2
Var_I               =E_Isq - EI_sq;
M9                  =sqrt(Var_I) ;

%- M10. Ratio of Income Variance Decomposition
Var_I_within    =sum(var(C,alphapbmat(1,:),2).*xpbmat(:,1));                % within income variance: 
                                                                            % first compute the variance of C (income) across alpha shocks, within each x-type (equivalently within each y-type), using the pdf of alpha as weights
                                                                            % second: compute the mean of these variances over x-types (equiv. y-types), taking the pdf of x as weights.  
                                                                  
% within-x and between-x variance of income
Var_I_between   =var(sum(C.*alphapbmat(1,:),2),xpbmat(:,1)',1);             % between income variance 
                                                                            % first: compute the mean of C (income) across alpha shocks (within each x-type/for any given x-type), using the alphapdf as weights;
                                                                            % second:compute the variance of these within-means across x-types (equiv y-types), taking the pdf of x-types into account. 
                                                                    
M10             =Var_I_within/Var_I_between ;




% All moments

Mmodel=[M1;M2;M3M7(1,:)';M8;M9;M10];

Mmodel(isnan(Mmodel))=9999;

if length(Mmodel)<length(Mdata)
    Mmodel=ones(length(Mdata),1)*9999;
end


Moments =[Mmodel Mdata]                                                     % col 1 model moments, col 2 data moments

% Objective function

momcond=Mmodel-Mdata;

F=momcond'*Weight*momcond % (1x10)x(10x10)x(10x1) = 1x1


end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



