%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Chade and Lindenlaub
% Risky Matching
% December 2020
% Replication Codes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Description of file.

% This file inputs parameter estimates and empirical distributions to 
% conduct post estimation analysis and to plot the empirical and estimated
% distributions. 
%
% This file reproduces all figures and tables pertaining to the estimation
% and distributions.

% Comment: In the code below, '1980' refers to 1979-1981 (the early period)
% and '2015' refers to 2015-2017 (the later period)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% PREPARATION

%----------------------------- PRELIMINARIES -----------------------------%

clear all

global Par          % Parameters strcture
global G            % Grids structure

cd('~/Replication_Codes_submit/Estimation/Estimation_Code')
addpath(genpath('~/Replication_Codes_submit'));
addpath(genpath('~/Replication_Codes_submit/Estimation'));
addpath(genpath('~/Replication_Codes_submit/Estimation/Wage_Data'));
addpath(genpath('~/Replication_Codes_submit/Estimation/Counterfactuals_Code'));
addpath(genpath('~/Replication_Codes_submit/Estimation/Output'));
addpath(genpath('~/Replication_Codes_submit/Statistical_Decomp'));

fname = '~/Replication_Codes_submit/Estimation/Output';

%----------------------------- LOAD ESTIMATED PARAMETERS -----------------%

%%% Import Estimated Parameters from Both Periods

% Early period: Estimated parameters
load('gmm_output_1980original_fminsearch.mat','X')
params_1=X;

% Later period: Estimated parameters
params_2=X(1,1); % obtain cost parameter from early period
load('gmm_output_2015original_fminsearch.mat','X')
params_2=[params_2  X];  


%% PLOT CDF's

%--L-DISTRIBUTION --------------------------------------------------------%

Par.Ngrid_alpha     =1000; 

Par.tau1            =params_1(3);                                           % std deviation of shock alpha, 1980
Par.tau2            =params_2(3);                                           % std deviation of shock alpha, 2015
Par.alphabar        =0;                                                     % mean of shock alpha

Par.alpha_lb1       =Par.alphabar-3*Par.tau1;                               % for normal: +- 3 standard deviations around the mean, 1980
Par.alpha_ub1       =Par.alphabar+3*Par.tau1;   

Par.alpha_lb2       =Par.alphabar-3*Par.tau2;                               % for normal: +- 3 standard deviations around the mean, 2015
Par.alpha_ub2       =Par.alphabar+3*Par.tau2;   

G.alphamat1         =linspace(Par.alpha_lb1,Par.alpha_ub1,Par.Ngrid_alpha); % support of alpha shock, 1980 
G.alphamat2         =linspace(Par.alpha_lb2,Par.alpha_ub2,Par.Ngrid_alpha); % support of alpha shock, 2015

alpha_cdf1          =normcdf(G.alphamat1,Par.alphabar,Par.tau1);            % shock cdf, 1980       
alpha_cdf2          =normcdf(G.alphamat2,Par.alphabar,Par.tau2);            % shock cdf, 2015     

% plot (Figure 3, left, in paper)
figure(1)
plot(G.alphamat1,alpha_cdf1,'LineWidth',1.5)
hold on
plot(G.alphamat2, alpha_cdf2,'LineWidth',1.5)
legend('1980', '2015', 'FontSize', 12)
grid off;
xlabel('\alpha', 'FontWeight','b','FontSize',12);
ylabel('L(\alpha)', 'FontWeight','b','FontSize',12);
title('', 'FontWeight','b','FontSize',12);
hold off
saveas(gcf,fullfile(fname, 'Figure3_1.eps'),'epsc')  


%--Q-DISTRIBUTION --------------------------------------------------------%

%- load ability distribution Q (data)

% 1980
G.q_dist        = importdata('Wage_Data/Q_early.csv');                      % q_dist.data is the vector of theta's from the data
G.q_dist.data   = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));
q1              = G.q_dist.data;                                            % q density, 1980

% 2015
G.q_dist        = importdata('Wage_Data/Q_later.csv');                      % q_dist.data is the vector of theta's from the data
G.q_dist.data   = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));
q2              = G.q_dist.data;                                            % q density, 2015

%- plot    (Figure 4, left, in paper)
figure(2)
cdfplot(q1)
hold on
cdfplot(q2)
legend('1980', '2015', 'FontSize', 12)
grid off;
xlabel('\theta', 'FontWeight','b','FontSize',12);
ylabel('Q(\theta)', 'FontWeight','b','FontSize',12);
title('', 'FontWeight','b','FontSize',12);
hold off
saveas(gcf,fullfile(fname,'Figure4_1.eps'),'epsc')  



%--G-DISTRIBUTION --------------------------------------------------------%

%- load firm distribution G (data)
%  (this is a FREQUENCY distribution, i.e. gives the y-level for each job)

G.G_dist    = importdata('Wage_Data/G_expanded_early.csv');                 % G_dist.data is the vector of y's from the data, 1980
g1          = G.G_dist.data;

G.G_dist    = importdata('Wage_Data/G_expanded_later.csv');                 % G_dist.data is the vector of y's from the data, 2015
g2          = G.G_dist.data;

%- plot (Figure 4, right, in paper)
figure(4)
[~,~]=cdfplot(g1);
hold on
[~,~]=cdfplot(g2);
legend('1980', '2015', 'FontSize', 12)
grid off;
xlabel('y', 'FontWeight','b','FontSize',12);
ylabel('G(y)', 'FontWeight','b','FontSize',12);
title('', 'FontWeight','b','FontSize',12);
hold off
saveas(gcf,fullfile(fname, 'Figure4_2.eps'),'epsc')  

%--TECHNOLOGY f ----------------------------------------------------------%

% skill grid
Par.Ngrid_x  =1000;
G.xmat       =linspace(1/Par.Ngrid_x,1,Par.Ngrid_x);                        % skill x-grid

y_mean1         =mean(g1);                                                  % mean of y-distribution, 1980
y_mean2         =mean(g2);                                                  % mean of y-distribution, 2015
f1              =params_1(4)*(G.xmat.^params_1(5)).*y_mean1^params_1(6)+params_1(7);   % technology f, 1980
f2              =params_2(4)*(G.xmat.^params_2(5)).*y_mean2^params_2(6)+params_2(7);   % technology f, 2015

%- plot [Figure 6 in the paper]
figure(5)
plot(G.xmat, f1, 'LineWidth',2)
hold on
plot(G.xmat, f2,  'LineWidth',2)
legend('1980', '2015', 'FontSize', 12)
grid off;
xlabel('x', 'FontWeight','b','FontSize',12);
ylabel('f(x)', 'FontWeight','b','FontSize',12);
title('', 'FontWeight','b','FontSize',12);
hold off
saveas(gcf, fullfile(fname, 'Figure6.eps'),'epsc')  

% housekeeping
clear y_mean1 y_mean2 f1 f2;


%% COMPUTE EQ OF ESTIMATED MODEL

%- Set Parameters for both periods

% shock grid
Par.Ngrid_alpha =1000;

% utility function risk aversion parameter (CRRA)
Par.sigma       =1.1;

% skill distribution, H_n and H_e (FOSD)
Par.Ngrid_x     =1000;                                                      % skill x-grid: number of grid points
Par.b_n         =1;                                                         % b_n = 1: uniform distribution
G.xmat          =linspace(1/Par.Ngrid_x,1,Par.Ngrid_x);                     % skill x-grid

% Tolerance 
Par.tolerance   =0.00001;
Par.tolerance_nan=0.0005;

% Seed
Par.seed        =1984;

% Effort Cost 
Par.lambda      =params_1(1,1);                                             % fix cost parameter in 2015 to estimated cost parameter from 1980 
Par.p=1;

% Scale of Shock (normalize)
Par.r           =1;

% Mean of alpha shock (normalize)
Par.alphabar    =0;

% Discounting
Par.disc        =1/(1+0.04/12);                                             % monthly


%----------------------------- 1980 --------------------------------------%

%- Load Distributions

% load firm distribution G  
G.G_dist        = importdata('Wage_Data/G_expanded_sample_early.csv');      % G_dist.data is the vector of y's from the data

% load ability distribution Q
G.q_dist        = importdata('Wage_Data/Q_early.csv');                      % q_dist.data is the vector of theta's from the data
G.q_dist.data   = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));

%- number of individuals we simulate
Par.sim_no      =length(G.G_dist.data);                                     % equals the number of jobs in the data


%- Load Moments

% M1: College Share
Col_Share   =csvread('Wage_Data/college_share.csv',1,0);
Mdata1980   =mean(Col_Share(4:6,2));

% M2: College Premium
Col_Prem    =csvread('Wage_Data/college_premium.csv',1,5);
Mdata1980   =[Mdata1980 mean(Col_Prem(4:6,1))];

% M3-7: Income Percentiles
Inc_Perc    =csvread('Wage_Data/percentiles.csv',1,0);
Mdata1980   =[Mdata1980 Inc_Perc(1,1) Inc_Perc(5,1) Inc_Perc(10,1) Inc_Perc(15,1) Inc_Perc(19,1)];

% M8: Mean Income
Inc_Mom     =csvread('Wage_Data/moments.csv',1,1);
Mdata1980   =[Mdata1980 Inc_Mom(1,1)];

% M9: Std Dev of Income
Mdata1980   =[Mdata1980 Inc_Mom(1,2)];

% M10: Var Decomp
Var_Decomp  =csvread('Wage_Data/inc_var.csv',1,1);
Mdata1980   =[Mdata1980 Var_Decomp(1,3)/Var_Decomp(1,4)];

Mdata       =Mdata1980';

%- Load Weighting Matrix
Weighting_imp=load('Weighting_Matrix/Weight_early.mat');
Weight      =Weighting_imp.Weight;

%- Estimated Parameters 1980
params      =params_1;

%- Solve the model
[F_1, Moments_1, theta_1]=moments_1980_final(G, Par, params, Mdata, Weight);





%----------------------------- 2015 --------------------------------------%


%- Load Distributions

% load firm distribution G  
G.G_dist        = importdata('Wage_Data/G_expanded_sample_later.csv');      % G_dist.data is the vector of y's from the data, RANDOM SAMPLE
    
% load ability distribution Q
G.q_dist        = importdata('Wage_Data/Q_later.csv');                      % q_dist.data is the vector of theta's from the data
G.q_dist.data   = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));


%- Load Moments

% M1: College Share
Col_Share   =csvread('Wage_Data/college_share.csv',1,0);
Mdata2015   =mean(Col_Share(40:42,2));

% M2: College Premium
Col_Prem    =csvread('Wage_Data/college_premium.csv',1,5);
Mdata2015   =[Mdata2015 mean(Col_Prem(40:42,1))];

% M3-7: Income Percentiles
Inc_Perc    =csvread('Wage_Data/percentiles.csv',1,0);
Mdata2015   =[Mdata2015 Inc_Perc(1,2) Inc_Perc(5,2) Inc_Perc(10,2) Inc_Perc(15,2) Inc_Perc(19,2)];

% M8: Mean Income
Inc_Mom     =csvread('Wage_Data/moments.csv',1,1);
Mdata2015   =[Mdata2015 Inc_Mom(2,1)];

% M9: Std Dev of Income
Mdata2015   =[Mdata2015 Inc_Mom(2,2)];

% M10: Var Decomp
Var_Decomp  =csvread('Wage_Data/inc_var.csv',1,1);
Mdata2015   =[Mdata2015 Var_Decomp(2,3)/Var_Decomp(2,4)];

Mdata       =Mdata2015';


%- Load Weighting Matrix
Weighting_imp   = load('Weighting_Matrix/Weight_later.mat');
Weight          = Weighting_imp.Weight;

%- Estimated Parameters 2015
params=params_2(2:end);

%- Solve the model
[F_2, Moments_2, theta_2]=moments_2015_final(G, Par, params, Mdata, Weight);



%% TABLES AND FIGURES 

%- Table: Exogenous Parameters (Table 4 in paper)
Output_Table_params_exog =[{Par.disc 'Monthly Discount Rate' 'Standard'} ; {Par.sigma 'Risk Aversion' 'In Standard Range for CRRA'}; {Par.alphabar 'Mean of Shock' 'normalization'}];
latextable(Output_Table_params_exog, 'Vert',{'$\beta$','$\sigma$','$\bar \alpha$'},'Horiz',{'\textbf{Value}','\textbf{Parameter Description}', '\textbf{Notes}'},'format', '%3.3f', 'save','Table4', 'name',fullfile(fname,'Table4'));

%- Table: Parameter Estimates (Table 1 in paper)
Output_Table_params =[{params_1(1,1) params_2(1,1) 'Effort Cost Parameter'}; {params_1(1,2) params_2(1,2) 'Skill Risk'}; {params_1(1,3) params_2(1,3) 'Standard Deviation of Shock'} ;{params_1(1,4) params_2(1,4)  'TFP'};{params_1(1,5) params_2(1,5) 'Elasticity of $f$ in $x$'}; {params_1(1,6) params_2(1,6) 'Elasticity of $f$ in $y$'}; {params_1(1,7) params_2(1,7) 'Constant in $f$'}];
latextable(Output_Table_params, 'Vert',{'$\lambda$','$b$', '$\tau$', '$q$', '$\gamma_1$', '$\gamma_2$', '$K$'},'Horiz',{'\textbf{Estimate 1980}',	'\textbf{Estimate 2015}', '\textbf{Parameter Description}'}, 'format' ,'%3.2f', 'tableColumnAlignment', 'l', 'save','Table1', 'name',fullfile(fname,'Table1'));

%- Table: Fit (Data and Model Moments)
% 1980 (Table 5 in paper)
latextable(Moments_1, 'Vert',{'$1-Q(\theta^*)$','$\frac{\mathbb E[\iota|\theta\ge\theta^*]}{\mathbb E[\iota|\theta<\theta^*]}$', '$i_{5}$', '$i_{25}$','$i_{50}$','$i_{75}$','$i_{95}$', '$\mathbb E[\iota]$','$\sqrt{Var[\iota]}$','$\frac{Var[\iota]^{within}}{{Var}[\iota]^{between}}$'},'Horiz',{'\textbf{Data}',	'\textbf{Model}'}, 'format', '%3.2f','save','Table5', 'name',fullfile(fname,'Table5'));
% 2015 (Table 6 in paper)
latextable(Moments_2, 'Vert',{'$1-Q(\theta^*)$','$\frac{\mathbb E[\iota|\theta\ge\theta^*]}{\mathbb E[\iota|\theta<\theta^*]}$', '$i_{5}$', '$i_{25}$','$i_{50}$', '$i_{75}$','$i_{95}$', '$\mathbb E[\iota]$','$\sqrt{Var[\iota]}$','$\frac{{Var}[\iota]^{within}}{{Var}[\iota]^{between}}$'},'Horiz',{'\textbf{Data}',	'\textbf{Model}'}, 'format', '%3.2f','save','Table6', 'name',fullfile(fname,'Table6'));



%- Plot: Fit (Data and Model Moments)

% Plot model moments against data moments along with 45 degree line
Moments_1(3:9,:)=Moments_1(3:9,:)./100;                                     %- rescale M3-9 just for the graph
Moments_2(3:9,:)=Moments_2(3:9,:)./100;                                     %- rescale M3-9 just for the graph

x = linspace(-0.5,80); 
y = x;

% Figure: Fit 1980  (Figure 5, left, in paper)
figure(6)
scatter(Moments_1(:,2), Moments_1(:,1))
hold on
plot(x,y)
hold off
xlabel('DATA') 
ylabel('MODEL') 
saveas(gcf, fullfile(fname,'Figure5_1.eps'),'epsc')  

% Figure: Fit 2015 (Figure 5, right, in paper)
figure(7)
scatter(Moments_2(:,2), Moments_2(:,1))
hold on
plot(x,y)
hold off
xlabel('DATA') 
ylabel('MODEL') 
saveas(gcf, fullfile(fname,'Figure5_2.eps'),'epsc')  



%--H-DISTRIBUTION --------------------------------------------------------%

% skill distribution H
Par.Ngrid_x  =1000;
G.xmat       =linspace(1/Par.Ngrid_x,1,Par.Ngrid_x);                        % skill x-grid

% skill distribution non-educated, for H_n
Par.b_n      =1;                                                            % b_n = 1: uniform distribution

% H_n cdf
xn_cdf      =(G.xmat).^Par.b_n;                                             % H_n: cdf of non-educated

% skill distribution educated, for H_e
Par.b_e1    =params_1(2);                              
Par.b_e2    =params_2(2);                              

% H_e cdf
xe_cdf1     =(G.xmat).^Par.b_e1;                                            % H_e: cdf of educated 1980       
xe_cdf2     =(G.xmat).^Par.b_e2;                                            % H_e: cdf of educated 2015       

% ability cdf

[Q1, p1]    = ecdf(q1);                                                     % evalulate empirical ability distribution Q at different ability values (here denoted by p), input is the vector of theta's from the data
dist        = abs(p1 - theta_1);                                            % find ability level p that is closest to theta_1, which is eq theta* coming out of estimation early period
minDist     = min(dist);
idx         = find(dist == minDist);
Q_theta1    = Q1(idx);                                                      % evaluate Q at theta --> Q(theta), 1980

[Q2, p2]    = ecdf(q2);                                                     % evalulate empirical ability distribution Q at different ability values (here called p), input is the vector of theta's from the data
dist        = abs(p2 - theta_2);                                            % find ability level p that is closest to theta_2, which is eq theta* coming out of estimation later period
minDist     = min(dist);
idx         = find(dist == minDist);
Q_theta2    = Q2(idx);                                                      % evaluate Q at theta --> Q(theta), 2015

Q_theta1    = max(Q_theta1);                                                % Q_theta should be unique but if it is not, pick max of the vector
Q_theta2    = max(Q_theta2);                                                % Q_theta should be unique but if it is not, pick max of the vector

% skill pdf
x_cdf1      = Q_theta1*xn_cdf + (1-Q_theta1)*xe_cdf1;                       % H(x) is mixture of H_n and H_e, ability is distributed according to Q, 1980
x_cdf2      = Q_theta2*xn_cdf + (1-Q_theta2)*xe_cdf2;                       % H(x) is mixture of H_n and H_e, ability is distributed according to Q, 2015

% plot (Figure 3, right, in paper)
figure(3) 
plot(G.xmat, x_cdf1, 'LineWidth',2)
hold on
plot(G.xmat,x_cdf2,  'LineWidth',2)
legend('1980', '2015', 'FontSize', 12)
grid off;
xlabel('x', 'FontWeight','b','FontSize',12);
ylabel('H(x)', 'FontWeight','b','FontSize',12);
title('', 'FontWeight','b','FontSize',12);
hold off
saveas(gcf, fullfile(fname, 'Figure3_2.eps'),'epsc')  

% housekeeping
clear x_cdf1 x_cdf2 Q_theta1 Q_theta2 theta_1 theta_2 xe_cdf1 xe_cdf2 xn_cdf2e

%% DECOMPOSITION

%- Load results from decomposition
load('Decomp_theta_sep.mat');
load('Decomp_skillpremium_sep.mat');
load('Decomp_7525_sep.mat');

%- Table: Decomposition of Income Inequality Changes (75-25 ratio) (Table 2 in paper)
Decomp_7525_sep=cell2mat(Decomp_7525_sep(:,1:2));
Output_Table_Decomp_7525=[Decomp_7525_sep(1,:); Decomp_7525_sep(8,:); Decomp_7525_sep(2:7,:)];
latextable(Output_Table_Decomp_7525, 'Vert',{'$1980$','$2015$', '$G$', '$H_1$','$Q$', '$L$','$f$', 'Skill Premium'},'Horiz',{'\textbf{$i_{75}/i_{25}$}',	'\textbf{\%-Change rel. to 1980}'}, 'format', '%3.2f','save','Table2', 'name',fullfile(fname,'Table2'));

%- Table: Decomposition of Skill Premium Changes (Table 7 in paper)
Decomp_skillpremium_sep=cell2mat(Decomp_skillpremium_sep(:,1:2));
Output_Table_Decomp_skill=[Decomp_skillpremium_sep(1,:); Decomp_skillpremium_sep(8,:); Decomp_skillpremium_sep(2:6,:)];
latextable(Output_Table_Decomp_skill, 'Vert',{'$1980$','$2015$', '$G$', '$H_1$','$Q$', '$L$','$f$'},'Horiz',{'\textbf{Skill Premium}',	'\textbf{\%-Change rel. to 1980}'}, 'format', '%3.3f','save','Table7', 'name',fullfile(fname,'Table7'));

%- Table: Decomposition of Theta Changes (Table 8 in paper)
Decomp_theta_sep=cell2mat(Decomp_theta_sep(:,1:2));
Output_Table_Decomp_education=[Decomp_theta_sep(1,:); Decomp_theta_sep(8,:); Decomp_theta_sep(2:7,:)];
latextable(Output_Table_Decomp_education, 'Vert',{'$1980$','$2015$', '$G$', '$H_1$','$Q$', '$L$','$f$','Skill Premium'},'Horiz',{'\textbf{$1-Q(\theta)$}',	'\textbf{\%-Change rel. to 1980}'}, 'format', '%3.3f','save','Table8', 'name',fullfile(fname,'Table8'));



%% FIXED THETA: COMPUTE EQ OF ESTIMATED MODEL

clear params_1 params_2

%----------------------------- 1980 --------------------------------------%

%- Load Distributions

% load firm distribution G  
G.G_dist        = importdata('Wage_Data/G_expanded_sample_early.csv');      % G_dist.data is the vector of y's from the data

% load ability distribution Q
G.q_dist        = importdata('Wage_Data/Q_early.csv');                      % q_dist.data is the vector of theta's from the data
G.q_dist.data   = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));

%- Early period: Estimated parameters
load('Counterfactuals_Code/gmm_output_1980original_fminsearch_fixedtheta.mat','X')
params_1        = X;

%- Fix theta* exogenously (from data)
Col_Share_1   =csvread('Wage_Data/college_share.csv',1,0);
Col_Share_1   =mean(Col_Share_1(4:6,2));                                    % College Share 1980 (1-Q(theta))
Q_theta_1     =1-Col_Share_1;

dist        = abs(Q1 - Q_theta_1);                                          % distance between Q2(theta) and the empirical Q_theta_1, where Q_theta_1==1-Col_Share_1
minDist     = min(dist);                                                    % find minimum distance
idx         = find(dist == minDist);
Par.theta   = p1(idx);                                                      % find theta that corresponds to Q_theta_1


%- Take Educ Share out of Moments
Mdata           = Mdata1980(2:end)';

%- Load Weighting Matrix
Weighting_imp   = load('Weighting_Matrix/Weight_early_fixedtheta.mat');
Weight          = Weighting_imp.Weight;

[F_1_fixedtheta, Moments_1_fixedtheta]=moments_fixedtheta_final(G, Par, params_1, Mdata, Weight);


%----------------------------- 2015 --------------------------------------%

%- Load Distributions

% load firm distribution G  
G.G_dist        = importdata('Wage_Data/G_expanded_sample_later.csv');      % G_dist.data is the vector of y's from the data
    
% load ability distribution Q
G.q_dist        = importdata('Wage_Data/Q_later.csv');                      % q_dist.data is the vector of theta's from the data
G.q_dist.data   = repelem(G.q_dist.data(:,2),G.q_dist.data(:,1));

%- Load Estimated parameters: 2015
load('gmm_output_2015original_fminsearch_fixedtheta.mat','X')
params_2        = X;  

%- Fix theta* exogenously (from data)
Col_Share_2   =csvread('Wage_Data/college_share.csv',1,0);                  
Col_Share_2   =mean(Col_Share_2(40:42,2));                                  % College Share 2015 (1-Q(theta))
Q_theta_2     =1-Col_Share_2;

dist        = abs(Q2 - Q_theta_2);                                          % distance between Q2(theta) and the empirical Q_theta_2
minDist     = min(dist);                                                    % find minimum distance
idx         = find(dist == minDist);
Par.theta   = p2(idx);                                                      % find theta that corresponds to Q_theta_2

%- Take Educ Share out of Moments
Mdata           = Mdata2015(2:end)';

%- Load Weighting Matrix
Weighting_imp   = load('Weighting_Matrix/Weight_later_fixedtheta.mat');
Weight          = Weighting_imp.Weight;

[F_2_fixedtheta, Moments_2_fixedtheta]=moments_fixedtheta_final(G, Par, params_2, Mdata, Weight);


%% FIXED THETA: TABLES AND FIGURES

%- Table: Parameter Estimates (Table 9 in paper)
Output_Table_Params_theta=[{params_1(1,1) params_2(1,1) 'Skill Risk'}; {params_1(1,2) params_2(1,2) 'Standard Deviation of Shock'} ;{params_1(1,3) params_2(1,3) 'TFP'}; {params_1(1,4) params_2(1,4) 'Curvature of $f$ in $x$'}; {params_1(1,5) params_2(1,5) 'Curvature of $f$ in $y$'}; {params_1(1,6) params_2(1,6) 'Constant in $f$'}];
latextable(Output_Table_Params_theta, 'Vert',{'$b$', '$\tau$', '$q$', '$\gamma_1$', '$\gamma_2$', '$K$'},'Horiz',{'\textbf{Estimate 1980}',	'\textbf{Estimate 2015}', '\textbf{Parameter Description}'},'format' ,'%3.2f', 'tableColumnAlignment', 'l', 'save','Table9', 'name',fullfile(fname,'Table9'));

%- Fit (Data and Model Moments)

% Table: 1980 (Table 10 in paper)
Output_Table_Moments_1_theta=Moments_1_fixedtheta;
latextable(Output_Table_Moments_1_theta, 'Vert',{'$\frac{\mathbb E[\iota|\theta\ge\theta^*]}{\mathbb E[\iota|\theta<\theta^*]}$', '$i_{5}$', '$i_{25}$','$i_{50}$','$i_{75}$','$i_{95}$', '$\mathbb E[\iota]$','$\sqrt{Var[\iota]}$','$\frac{Var[\iota]^{within}}{{Var}[\iota]^{between}}$'},'Horiz',{'\textbf{Data}',	'\textbf{Model}'}, 'format', '%3.2f','save','Table10', 'name',fullfile(fname,'Table10'));

% Table: 2015 (Table 11 in paper)
Output_Table_Moments_2_theta=Moments_2_fixedtheta;
latextable(Output_Table_Moments_2_theta, 'Vert',{'$\frac{\mathbb E[\iota|\theta\ge\theta^*]}{\mathbb E[\iota|\theta<\theta^*]}$', '$i_{5}$', '$i_{25}$','$i_{50}$', '$i_{75}$','$i_{95}$', '$\mathbb E[\iota]$','$\sqrt{Var[\iota]}$','$\frac{{Var}[\iota]^{within}}{{Var}[\iota]^{between}}$'},'Horiz',{'\textbf{Data}',	'\textbf{Model}'}, 'format', '%3.2f','save','Table11', 'name',fullfile(fname,'Table11'));

%-housekeeping
clear alpha_cdf1 alpha_cdf2 Col_Prem Col_Share Col_Share_1 Col_Share_2 dist distribution f1 f2 F_1 F_1_fixedtheta F_2 F_2_fixedtheta g1 G1 g2 G2 idx Inc_Mom Inc_Perc Mdata Mdata1980 Mdata2015 minDist Moments_1 Moments_1_fixedtheta Moments_2 Moments_2_fixedtheta p1 p2 params params_1 params_2 q1 Q1 q2 Q2 Qtheta1 Qtheta2 Q_theta_1 Q_theta_2 Weight Weighting_imp x X x_cdf1 x_cdf2  xn_cdf y 

%% FIXED THETA: DECOMPOSITION

%- Load results from decomposition under counterfactual model with exogenous Theta^*
load('Decomp_skillpremium_sep_fixedtheta.mat');
load('Decomp_7525_sep_fixedtheta.mat');

%- Load results from statistical decomposition
Stat_Decomp         = csvread('Statistical_Decomp/counterfactuals.csv',1,1);
Decomp_1980         = Stat_Decomp(1,3);
Decomp_educ         = Stat_Decomp(2,3);
Decomp_2015         = Stat_Decomp(3,3);
Decomp_wagecondeduc = Stat_Decomp(4,3);

% compute percentage change in 75/25 ratio for various cases
Decomp_1980_perc    = Stat_Decomp(1,8) - Stat_Decomp(1,8);
Decomp_2015_perc    = Stat_Decomp(3,8) - Stat_Decomp(1,8);
Decomp_wagecondeduc_perc=Stat_Decomp(4,8) - Stat_Decomp(1,8);
Decomp_educ_perc    = Stat_Decomp(2,8) - Stat_Decomp(1,8);

%- Table: Decomposition of Income Inequality Changes (75-25 ratio) (Table 13 in paper)
Decomp_7525_sep=cell2mat(Decomp_7525_sep(:,1:2));
Output_Table_Decomp_7525_theta=[Decomp_7525_sep(1,:); Decomp_7525_sep(9,:); Decomp_7525_sep(2:8,:)];
latextable(Output_Table_Decomp_7525_theta, 'Vert',{'$1980$','$2015$', '$G$', '$H_1$','$Q$', '$L$','$f$','Skill Premium','Education'},'Horiz',{'\textbf{$w_{75}/w_{25}$}',	'\textbf{\%-Change rel. to 1980}'}, 'format', '%3.2f','save','Table13', 'name',fullfile(fname,'Table13'));

%- Table: Decomposition of Skill Premium Changes (Table 12 in paper)
Decomp_skillpremium_sep=cell2mat(Decomp_skillpremium_sep(:,1:2));
Output_Table_Decomp_skill_theta=[Decomp_skillpremium_sep(1,:); Decomp_skillpremium_sep(9,:); Decomp_skillpremium_sep(2:6,:)];
latextable(Output_Table_Decomp_skill_theta, 'Vert',{'$1980$','$2015$', '$G$', '$H_1$','$Q$', '$L$','$f$'},'Horiz',{'\textbf{Skill Premium}',	'\textbf{\%-Change rel. to 1980}'}, 'format', '%3.2f','save','Table12', 'name',fullfile(fname,'Table12'));

%- Table: Statistical Decomposition and fixed theta (Table 3 in paper)
Output_Table_Decomp_theta = [Decomp_1980 Decomp_1980_perc Decomp_7525_sep(1,:); ... % 1980
    Decomp_2015 Decomp_2015_perc Decomp_7525_sep(9,:); ...                          % 2015
    Decomp_wagecondeduc Decomp_wagecondeduc_perc Decomp_7525_sep(7,:); ...          % wages conditional on educ
    Decomp_educ Decomp_educ_perc Decomp_7525_sep(8,:);];                            % education
latextable(Output_Table_Decomp_theta, 'Vert',{'$1980$','$2015$', '$wages|education$', '$education$'},'Horiz',{'\textbf{$i_{75}/i_{25}$}',	'\textbf{\%-Change rel. to 1980}', '\textbf{$w_{75}/w_{25}$}',	'\textbf{\%-Change rel. to 1980}'}, 'format', '%3.2f','save','Table3', 'name',fullfile(fname,'Table3'));

