
***--------------------------------------------------------------------------***
 //* Chade and Lindenlaub
 //* Risky Matching
 //* December 2020
 //* Replication Codes
 //*
 //*** Description of file.
 //*
 //* Load ONET data to obtain Jobs' Cognitive Skill Requirements (later period).
 //*
 //* We conduct a principal component analysis on the variables 
 //* "Mathematical Reasoning", "Number Facility" and "Mathematics" to get a one 
 //* dimensional measure, which serves as the cognitive task content per census
 //* occupation. Save data for further analysis and create pca-eigenvalue figure
 //* and output table.
 //*
 //* Note: To reproduce results, random number generator needs to be re-set.
***--------------------------------------------------------------------------***


clear  		all
capture 	log close
set 		more off 

 
cd 			"~/Replication_Codes_submit/Occupational_Tasks/ONET"
global		onetdata "~/Replication_Codes_submit/Occupational_Tasks/ONET/Original_Data_O*NET"
global 		crosswalk "~/Replication_Codes_submit/Occupational_Tasks/ONET/Crosswalks"

set			seed 1984
*ssc 		install blindschemes




***--ASSEMBLE----------------------------------------------------------------***

* assemble O*NET raw files 
import 		excel "$onetdata/Abilities.xlsx", firstrow sheet("Abilities") clear
gen 		str20 origin = "abilities"
save 		"Abilities.dta", replace

import 		excel "$onetdata/Work Activities.xlsx", firstrow sheet("Work Activities") clear
gen 		str20 origin = "work activities"
save 		"Work Activities.dta", replace

import 		excel "$onetdata/Skills.xlsx", firstrow sheet("Skills") clear
gen 		str20 origin = "skills"
save 		"Skills.dta", replace

append 		using "Work Activities.dta"
append 		using "Abilities.dta"

save 		onet_all.dta, replace

erase 		"Abilities.dta"
erase 		"Work Activities.dta"
erase 		"Skills.dta"




***--PREPARATION-------------------------------------------------------------***

* keep the math related variables to make as consistent as possible with DOT data
use 		onet_all.dta, clear
drop 		if ElementName != "Mathematical Reasoning" & ElementName != "Number Facility" & ElementName != "Mathematics" 

* tidy up
drop 		if ScaleID == "IM"
drop 		StandardError *CIBound Date RecommendSuppress NotRelevant DomainSource ScaleID N ScaleName
rename 		DataValue onetscore

* convert to wide data set
egen 		occ = group(ONETSOCCode)
egen 		item = group(ElementID)

drop 		ElementID ElementName origin
reshape 	wide onetscore, i(occ) j(item)
drop 		occ 
aorder

* create SOC2010 codes by trimming ONETSOC10 codes
gen 		soc2010 = substr(ONETSOCCode,1,7)

* recode the one SOC2010 code missing from the soc_2000_to_2010 crosswalk
replace 	soc2010 = "19-1021" if soc2010=="19-1020"

* take means of O*NET scores by soc2010
collapse 	onetscore*, by(soc2010) fast

save 		onet.dta, replace




***--PCA---------------------------------------------------------------------***

* import 
use 		onet.dta, clear

* normalize onetscores
foreach 	v of varlist onetscore*	{
su 			`v'
replace 	`v' = (`v' - r(min))/(r(max)-r(min))
}

* pca	
pca 		onetscore*
predict 	pc1, score

* output table (Table 2 in the Online Appendix)
matrix ev = e(Ev)'
matrix roweq ev = ""
matrix colnames ev = "Eigenvalue"

matrix p = ev[1...,1] / e(trace)
matrix colnames p = "Proportion"

// I don't know a neat way of doing a cumulative sum
matrix c = J(e(trace),1,0)
matrix c[1,1] = p[1,1]
forvalues i=2/`e(trace)' {
    matrix c[`i',1] = c[`=`i'-1',1] + p[`i',1]
    }
matrix colnames c = "Cumulative"

matrix t = ( ev , p , c )
matrix list t

estadd matrix table = t

esttab using Table2_OnlineAppendix, replace ///
    cells("table[Eigenvalue](t) table[Proportion](t fmt(4)) table[Cumulative](t fmt(4))") ///
    nogap noobs nonumber nomtitle

* screeplot (Figure 2 in the Online Appendix)
screeplot, 	scheme(plotplain) title("")
gr 			export "Figure2_OnlineAppendix.eps", replace

keep 		soc2010 pc1

save 		onet_pca.dta, replace




***--CROSSWALK TO CENSUS-----------------------------------------------------***

* merge pca output with crosswalk so that we can link to census data
use 		onet_pca.dta, clear
merge 		1:m soc2010 using "$crosswalk/Crosswalk_census1990_soc2010"
keep 		if _merge==3 

* collapse PC to mean(PC) by census1990-occupation as we want one entry per occupation
collapse 	(mean) pc1, by(census1990)

* generate percentiles of PC
cumul       pc1, generate(y)
rename 		census1990 occ1990

* save
save 		onet_final.dta, replace

erase		onet_all.dta
erase 		onet.dta
erase		onet_pca.dta



