
***--------------------------------------------------------------------------***
 //* Chade and Lindenlaub
 //* Risky Matching
 //* December 2020
 //* Replication Codes
 //* 
 //*
 //*** Description of file.
 //*
 //* This code performs a statistical decomposition of wage inequality, 
 //* based on conditional (on education) wage distributions
 //* 
***--------------------------------------------------------------------------***


clear  		all
capture 	log close
set 		more off 

cd 			"~/Replication_Codes_submit/Statistical_Decomp"
global		wagedata "~/Replication_Codes_submit/Wage_Data"

* ssc 		install blindschemes




***--PREPARATION-------------------------------------------------------------***

* import data
use 		"$wagedata/cps_data.dta", clear

* time period restriction
keep 		if year >= 1979 & year <= 1981 | year >=2015 & year <= 2017

* education grouping
drop 		if educ == 999
tab 		educ
recode 		educ (0/72 = 1 "No or unclear highschool degree") (73 = 2 "Highschool graduates") (80/100 = 3 "Some college") (110/111 = 4 "Bachelor's degree") (120/125 = 5 "More than Bachelor's degree"), gen(educ_grouped)
label 		variable educ_grouped "education grouped"

* group wages into fine bins
keep 		year educ_grouped wage1999_level

qui 		sum wage1999_level, d
return 		list
gen 		wage1999_grouped = .
scalar 		max_wage = round(r(max)/10) -1

local 		i = 0
foreach 	a of numlist 0/`=scalar(max_wage)' {
replace 	wage1999_grouped = (`i'+1)*10 if wage1999_level > `i'*10 & wage1999_level <= (`i'+1)*10
local 		i = `i' + 1			
}
drop 		wage1999_level

save 		temporary_full.dta, replace




***--CREATE DATASETS---------------------------------------------------------***

// Early period: 1979 - 1981

* import data
use 		temporary_full.dta, clear

keep 		if year >= 1979 & year <= 1981
order 		educ_grouped, first
sort 		educ_grouped wage1999_grouped
drop 		year

* conditional wage & education distribution 
gen 		count_educ = _n 													 // total # of individuals
qui 		sum count_educ, d
return 		list 
scalar 		max_educ = r(max)													 // total # of individuals
collapse 	(count) count_educ, by(educ_grouped wage1999_grouped)				 // # of individuals in educ-wage bin
bys 		educ_grouped: gen sum_educ = sum(count_educ)						 
bys 		educ_grouped: replace sum_educ = sum_educ[_N]						 // # of indinividuals per educ bin
gen 		wage_pdf_cond = count_educ / sum_educ 								 // wage pdf conditional on education bin
gen 		educ_pdf = sum_educ / max_educ 										 // educ pdf
drop 		count_educ sum_educ
rename 		(wage_pdf_cond educ_pdf) (wage_pdf_cond_80 educ_pdf_80)
save 		wage_conditional_80.dta, replace									


// Later period: 2015 - 2017

* import data
use 		temporary_full.dta, clear

keep 		if year >= 2015 & year <= 2017
order 		educ_grouped, first
sort 		educ_grouped wage1999_grouped
drop 		year

* conditional wage & education distribution 
gen 		count_educ = _n
qui 		sum count_educ, d
return 		list
scalar 		max_educ = r(max)
collapse 	(count) count_educ, by(educ_grouped wage1999_grouped)
bys 		educ_grouped: gen sum_educ = sum(count_educ)
bys 		educ_grouped: replace sum_educ = sum_educ[_N]
gen 		wage_pdf_cond = count_educ / sum_educ
gen 		educ_pdf = sum_educ / max_educ
drop 		count_educ sum_educ
rename 		(wage_pdf_cond educ_pdf) (wage_pdf_cond_15 educ_pdf_15)
save 		wage_conditional_15.dta, replace


***--COUNTERFACTUALS---------------------------------------------------------***

* import data
use 		wage_conditional_80.dta, clear

* merge & tidy up
merge 		1:1 educ_grouped wage1999_grouped using wage_conditional_15.dta
sort 		educ_grouped wage1999_grouped
erase 		wage_conditional_80.dta
erase 		wage_conditional_15.dta
erase 		temporary_full.dta

replace 	wage_pdf_cond_80 = 0 if wage_pdf_cond_80 == .
replace 	wage_pdf_cond_15 = 0 if wage_pdf_cond_15 == .
bys 		educ_grouped: replace educ_pdf_80 = educ_pdf_80[_n-1] if educ_pdf_80 == .
bys 		educ_grouped: replace educ_pdf_15 = educ_pdf_15[_n-1] if educ_pdf_15 == .

* counterfactual wage distribution: wage pdf 80 - educ pdf 15
preserve
keep 		educ_grouped wage1999_grouped wage_pdf_cond_80 educ_pdf_15
gen 		wage_pdf_w80_e15 = wage_pdf_cond_80 * educ_pdf_15
collapse 	(sum) wage_pdf_w80_e15, by(wage1999_grouped)
save 		wage_pdf_w80_e15.dta, replace
restore

* counterfactual wage distribution: wage pdf 15 - educ pdf 80
preserve
keep 		educ_grouped wage1999_grouped wage_pdf_cond_15 educ_pdf_80
gen 		wage_pdf_w15_e80 = wage_pdf_cond_15 * educ_pdf_80
collapse 	(sum) wage_pdf_w15_e80, by(wage1999_grouped)
save 		wage_pdf_w15_e80.dta, replace
restore

* reality: wage pdf 80 - educ pdf 80
preserve
keep 		educ_grouped wage1999_grouped wage_pdf_cond_80 educ_pdf_80
gen 		wage_pdf_w80_e80 = wage_pdf_cond_80 * educ_pdf_80
collapse 	(sum) wage_pdf_w80_e80, by(wage1999_grouped)
save 		wage_pdf_w80_e80.dta, replace
restore

* reality: wage pdf 15 - educ pdf 15
preserve
keep 		educ_grouped wage1999_grouped wage_pdf_cond_15 educ_pdf_15
gen 		wage_pdf_w15_e15 = wage_pdf_cond_15 * educ_pdf_15
collapse 	(sum) wage_pdf_w15_e15, by(wage1999_grouped)
save 		wage_pdf_w15_e15.dta, replace
restore

* merge & tidy up
use 		wage_pdf_w80_e15.dta, clear
merge 		1:1 wage1999_grouped using wage_pdf_w15_e80.dta, nogen
merge 		1:1 wage1999_grouped using wage_pdf_w80_e80.dta, nogen
merge 		1:1 wage1999_grouped using wage_pdf_w15_e15.dta, nogen

erase 		wage_pdf_w80_e15.dta
erase 		wage_pdf_w80_e80.dta
erase 		wage_pdf_w15_e15.dta
erase 		wage_pdf_w15_e80.dta

label 		variable wage_pdf_w80_e15 " counterfactual wages 80 educ 15"
label 		variable wage_pdf_w15_e80 " counterfactual wages 15 educ 80"
label 		variable wage_pdf_w80_e80 " reality wage and educ 80"
label 		variable wage_pdf_w15_e15 " reality wage and educ 15"

save 		counterfactual_maindataset_full.dta, replace




***--OUTPUT: COUNTERFACTUAL SUMMARY STATS------------------------------------***

local 		counterfactual "w80_e15 w15_e80 w80_e80 w15_e15"

foreach 	counterfactual in w80_e15 w15_e80 w80_e80 w15_e15 {

* import
use 		counterfactual_maindataset_full.dta, clear

* expand wage distribution
keep 		wage1999_grouped wage_pdf_`counterfactual'
replace 	wage_pdf_`counterfactual' = round(wage_pdf_`counterfactual' * 100000)
expand 		wage_pdf_`counterfactual'
sort 		wage1999_grouped
drop 		if wage_pdf_`counterfactual' == 0
keep 		wage1999_grouped

* create matrix with different statistics
tempname 	mat_`counterfactual'
mat 		mat_`counterfactual'=J(1,5,.) // store results in matrix
// 90/10 ratio
qui 		sum wage1999_grouped, d
scalar 		p90 = r(p90)
scalar 		p10 = r(p10)
scalar 		ninetyten = p90 / p10
mat 		mat_`counterfactual'[1,1] = ninetyten
// 90/50 ratio
scalar 		p50 = r(p50)
scalar 		ninetyfifty = p90 / p50
mat 		mat_`counterfactual'[1,2] = ninetyfifty
// 75/25 ratio
scalar 		p75 = r(p75)
scalar 		p25 = r(p25)
scalar 		seventyfivetwentyfive = p75 / p25
mat 		mat_`counterfactual'[1,3] = seventyfivetwentyfive
// Standard Deviation of wage
scalar 		stdev = r(sd)
mat 		mat_`counterfactual'[1,4] = stdev
// Gini
gen 		cum_wage1999_grouped = sum(wage1999_grouped)
qui 		sum cum_wage1999_grouped
replace 	cum_wage1999_grouped = cum_wage1999_grouped  / r(max)
gen 		cum_nr = _n
qui 		sum cum_nr
replace 	cum_nr = cum_nr / r(max)
label 		variable cum_wage1999_grouped "cumulative share of wage income"
label 		variable cum_nr "cumulative share of people"
gen 		cum_nr_diff = cum_nr[_n] - cum_nr[_n-1]
gen 		area_temp = cum_nr_diff * cum_wage1999_grouped
gen 		area= sum(area_temp) 
replace 	area = area[_N]
gen 		gini = 1-2*area // the gini coefficient is 1-2*(area under the lorenz curve)
drop 		area_temp cum_nr_diff area
qui 		sum gini, meanonly
mat 		mat_`counterfactual'[1,5] = r(mean)

save 		dist_`counterfactual'.dta, replace

putexcel 	set "gini_`counterfactual'_v2.xlsx", sheet("gini_`counterfactual'") replace
putexcel 	A1 = ("ninetyten") B1 = ("ninetyfifty") C1 = ("seventyfivetwentyfive") D1 = ("sd") E1 =("gini") F1 = ("counterfactual") F2 = ("`counterfactual'") A2=matrix(mat_`counterfactual')
import 		excel gini_`counterfactual'_v2.xlsx, firstrow clear
erase 		gini_`counterfactual'_v2.xlsx
save 		gini_`counterfactual'_v2.dta, replace


}

erase 		counterfactual_maindataset_full.dta

* append 
use 		gini_w80_e80_v2.dta, clear
append 		using gini_w80_e15_v2.dta
append 		using gini_w15_e15_v2.dta
append 		using gini_w15_e80_v2.dta
erase 		gini_w80_e15_v2.dta
erase 		gini_w80_e80_v2.dta
erase 		gini_w15_e15_v2.dta
erase 		gini_w15_e80_v2.dta

erase 		dist_w15_e15.dta
erase 		dist_w80_e15.dta
erase 		dist_w80_e80.dta
erase 		dist_w15_e80.dta


* percentage changes
gen 		ninetyten_perc = ninetyten[_n]/ninetyten[1]
gen 		ninetyfifty_perc = ninetyfifty[_n]/ninetyfifty[1]
gen 		seventyfivetwentyfive_perc = seventyfivetwentyfive[_n]/seventyfivetwentyfive[1]
gen 		sd_perc = sd[_n]/sd[1]
gen 		gini_perc = gini[_n] / gini[1]
order 		counterfactual, first

export 		excel using "counterfactuals.xlsx", firstrow(var) replace
export 		delimited "counterfactuals.csv", replace






