***--------------------------------------------------------------------------***
 //* Chade and Lindenlaub
 //* Risky Matching
 //* December 2020
 //* Replication Codes
 //* 
 //*** Description of file.
 //*
 //* This code calculates the moments from the cps data as inputs into the estimation.
 //*
 //* The 10 moments are:
 //*
 //* 1.) Share of College Graduates
 //* 2.) College Premium
 //* 3.-7.) Percentiles 5, 25, 50, 75, 95
 //* 8.) Average wage
 //* 9.) Standard Deviation
 //* 10.) Ratio of within to between income variance 
 //*
 //* Comment: For simplicity, we label variables as "1980" and "2015" but refer
 //* to the early and late period, respectively.
 //*
***--------------------------------------------------------------------------***
 
 
clear 		all
capture 	log close
set 		more off 
 
cd 			"~/Replication_Codes_submit/Wage_Data"
global		onet "~/Replication_Codes_submit/Occupational_Tasks/ONET"
global		dot "~/Replication_Codes_submit/Occupational_Tasks/DOT"




***-- 1.) COLLEGE EDUCATION SHARE--------------------------------------------***

* import data
use 		cps_data.dta, clear

* for 25 to 50
gen 		educ_dummy_2550 = educ_dummy_detailed if age >= 25 & age <=50
collapse 	educ_dummy_2550, by(year)

save 		college_share.dta, replace
export 		delimited "college_share.csv", replace




***-- 2.) COLLEGE PREMIUM----------------------------------------------------***

* import data
use 		cps_data.dta, clear

collapse 	(mean) wage1999_level, by(educ_dummy_detailed year)

preserve 
keep 		if educ_dummy_detailed==0
rename 		(educ_dummy_detailed wage1999_level) (educ_dummy_nocol wage1999_level_nocol)
save 		cps_wage1999_level_noncollegewage.dta, replace
restore 

keep 		if educ_dummy_detailed==1
rename 		(educ_dummy_detailed wage1999_level) (educ_dummy_col wage1999_level_col)
merge 		1:1 year using cps_wage1999_level_noncollegewage.dta, nogen

erase 		cps_wage1999_level_noncollegewage.dta

gen 		cp_wage1999_level = wage1999_level_col/wage1999_level_nocol

save 		college_premium.dta, replace
export 		delimited "college_premium.csv", replace




***-- 3.-7.) PERCENTILES OF INCOME DISTRIBUTION---------------------------------***

* import data
use 		cps_data.dta, clear

preserve
keep 		if year==2015 | year==2016 | year==2017
gquantiles 	pctile_wage1999_level_2015 = wage1999_level, pctile percentiles(5(5)95) strict
keep 		year pctile_wage1999_level_2015
drop 		if missing(pctile_wage1999_level_2015)
drop 		year
gen 		nr = _n
save 		pctile_2015_wage1999_level.dta, replace
restore

keep 		if year== 1979 | year==1980 | year==1981 
gquantiles 	pctile_wage1999_level_1980 = wage1999_level, pctile percentiles(5(5)95) strict
keep 		year pctile_wage1999_level_1980
drop 		if missing(pctile_wage1999_level_1980)
drop 		year
gen 		nr = _n
merge 		1:1 nr using pctile_2015_wage1999_level.dta, nogen
gen 		percentile =5*nr
drop 		nr

erase 		pctile_2015_wage1999_level.dta

order 		percentile, last

save 		percentiles.dta, replace
export 		delimited "percentiles.csv", replace




***-- 8.-9.) AVERAGE WAGE & STANDARD DEV-----------------------------------***

* import data
use 		cps_data.dta, clear

preserve
keep 		if year==2015 | year==2016 | year==2017
collapse 	(mean) wage1999_level (sd) sd_wage1999_level = wage1999_level
gen 		year = 2015
save 		moments2015_wage1999_level.dta, replace
restore

preserve
keep 		if year== 1979 | year==1980 | year==1981
collapse 	(mean) wage1999_level (sd) sd_wage1999_level = wage1999_level
gen 		year = 1980
save 		moments1980_wage1999_level.dta, replace
restore

use 		moments1980_wage1999_level.dta
append 		using moments2015_wage1999_level.dta

erase 		moments2015_wage1999_level.dta
erase 		moments1980_wage1999_level.dta

gen 		id = _n
sort 		id
drop 		id

label 		define yearl 1980 "1979 to 1981" 2015 "2015 to 2017"
label 		values year yearl
order 		year, first

save 		moments.dta, replace
export 		delimited "moments.csv", replace




***-- 10.) INCOME VARIANCE DECOMPOSITION--------------------------------------***

* import data
use 		cps_data.dta, clear

* group identifier
keep 		if year == 1979 | year == 1980 | year ==1981 | year ==2015 | year ==2016 | year ==2017

gen 		group = 1 
replace 	group = 2 if year ==2015 | year ==2016 | year ==2017

local 		grp "1 2"
	
save 		cps_tmp.dta, replace

foreach grp in 1 2 {

	* load
	use 	cps_tmp.dta, clear
	
	* income variance decomposition
	keep 	if group == `grp'
	if group ==1 {
		merge m:1 occ1990 using "$dot/dot_final.dta"
		keep if _merge==3 
		drop _merge 
		}
	else if group ==2 {
		merge m:1 occ1990 using "$onet/onet_final.dta"
		keep if _merge==3 
		drop _merge 
		}
	
	reghdfe wage1999_level, abs(y, savefe) resid
	predict fwithin if e(sample), res
	predict fbetween if e(sample), xbd
	egen 	sfbetween_sd=sd(fbetween)
	gen 	sfbetween = sfbetween_sd*sfbetween_sd
	egen 	sfwithin_sd=sd(fwithin)
	gen 	sfwithin = sfwithin_sd*sfwithin_sd
	gen 	sftotal = sfwithin + sfbetween
	gen 	sftotal_sd = sfwithin_sd + sfbetween_sd

	quietly sum wage1999_level
	gen 	wage1999_level_var=r(sd)^2 											
	gen		wage1999_level_sd=r(sd)

	* create data frame of values
	gen 	within_sd_wage1999_level = sfwithin_sd
	gen 	between_sd_wage1999_level = sfbetween_sd
	gen 	within_wage1999_level = sfwithin
	gen 	between_wage1999_level = sfbetween
	keep 	if _n == _N
	keep 	within_sd_wage1999_level between_sd_wage1999_level within_wage1999_level between_wage1999_level

	save 	inc_var_group`grp'_wage1999_level.dta, replace
}

* put together
use 		inc_var_group1_wage1999_level.dta, clear
append 		using inc_var_group2_wage1999_level.dta
gen 		year = 1980 in 1
replace 	year = 2015 in 2

erase 		cps_tmp.dta 
erase 		inc_var_group1_wage1999_level.dta 
erase 		inc_var_group2_wage1999_level.dta

order 		year, first
 
save 		inc_var.dta, replace
export 		delimited "inc_var.csv", replace









